@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -99,7 +99,6 @@ extern char ZABBIX_EVENT_SOURCE[ZBX_SERVICE_NAME_LEN];
 #define	AGENT_ERROR	-5
 #define	GATEWAY_ERROR	-6
 #define	CONFIG_ERROR	-7
-#define	SIG_ERROR	-8
 
 #define SUCCEED_OR_FAIL(result) (FAIL != (result) ? SUCCEED : FAIL)
 const char	*zbx_sysinfo_ret_string(int ret);
@@ -149,8 +148,7 @@ zbx_timezone_t;
 #define zbx_timespec_compare(t1, t2)	\
 	((t1)->sec == (t2)->sec ? (t1)->ns - (t2)->ns : (t1)->sec - (t2)->sec)
 
-extern double	ZBX_DOUBLE_EPSILON;
-
+#define ZBX_DOUBLE_EPSILON	0.000001
 int	zbx_double_compare(double a, double b);
 
 /* item types */
@@ -176,7 +174,8 @@ typedef enum
 	ITEM_TYPE_SNMPTRAP,
 	ITEM_TYPE_DEPENDENT,
 	ITEM_TYPE_HTTPAGENT,
-	ITEM_TYPE_SNMP		/* 20 */
+	ITEM_TYPE_SNMP,
+	ITEM_TYPE_SCRIPT	/* 21 */
 }
 zbx_item_type_t;
 const char	*zbx_agent_type_string(zbx_item_type_t item_type);
@@ -208,6 +207,9 @@ extern const int	INTERFACE_TYPE_PRIORITY[INTERFACE_TYPE_COUNT];
 #define ZBX_FLAG_DISCOVERY_PROTOTYPE	0x02
 #define ZBX_FLAG_DISCOVERY_CREATED	0x04
 
+#define ZBX_HOST_PROT_INTERFACES_INHERIT	0
+#define ZBX_HOST_PROT_INTERFACES_CUSTOM		1
+
 typedef enum
 {
 	ITEM_AUTHTYPE_PASSWORD = 0,
@@ -437,6 +439,7 @@ zbx_graph_yaxis_types_t;
 
 /* runtime control options */
 #define ZBX_CONFIG_CACHE_RELOAD	"config_cache_reload"
+#define ZBX_SECRETS_RELOAD	"secrets_reload"
 #define ZBX_HOUSEKEEPER_EXECUTE	"housekeeper_execute"
 #define ZBX_LOG_LEVEL_INCREASE	"log_level_increase"
 #define ZBX_LOG_LEVEL_DECREASE	"log_level_decrease"
@@ -780,6 +783,17 @@ const char	*zbx_item_logtype_string(unsigned char logtype);
 
 #define ZBX_USER_ONLINE_TIME	600
 
+/* user role permissions */
+typedef enum
+{
+	ROLE_PERM_DENY = 0,
+	ROLE_PERM_ALLOW = 1,
+}
+zbx_user_role_permission_t;
+
+#define ZBX_USER_ROLE_PERMISSION_ACTIONS_DEFAULT_ACCESS		"actions.default_access"
+#define ZBX_USER_ROLE_PERMISSION_ACTIONS_EXECUTE_SCRIPTS	"actions.execute_scripts"
+
 /* user permissions */
 typedef enum
 {
@@ -793,6 +807,7 @@ typedef struct
 {
 	zbx_uint64_t	userid;
 	zbx_user_type_t	type;
+	zbx_uint64_t	roleid;
 }
 zbx_user_t;
 
@@ -935,13 +950,15 @@ zbx_task_t;
 #define ZBX_RTC_CONFIG_CACHE_RELOAD	8
 #define ZBX_RTC_SNMP_CACHE_RELOAD	9
 #define ZBX_RTC_DIAGINFO		10
+#define ZBX_RTC_SECRETS_RELOAD		11
 
 typedef enum
 {
 	HTTPTEST_AUTH_NONE = 0,
 	HTTPTEST_AUTH_BASIC,
 	HTTPTEST_AUTH_NTLM,
-	HTTPTEST_AUTH_NEGOTIATE
+	HTTPTEST_AUTH_NEGOTIATE,
+	HTTPTEST_AUTH_DIGEST
 }
 zbx_httptest_auth_t;
 
@@ -1090,9 +1107,10 @@ int	calculate_item_nextcheck(zbx_uint64_t seed, int item_type, int simple_interv
 int	calculate_item_nextcheck_unreachable(int simple_interval, const zbx_custom_interval_t *custom_intervals,
 		time_t disable_until);
 time_t	calculate_proxy_nextcheck(zbx_uint64_t hostid, unsigned int delay, time_t now);
-int	zbx_check_time_period(const char *period, time_t time, int *res);
+int	zbx_check_time_period(const char *period, time_t time, const char *tz, int *res);
 void	zbx_hex2octal(const char *input, char **output, int *olen);
 int	str_in_list(const char *list, const char *value, char delimiter);
+int	str_n_in_list(const char *list, const char *value, size_t len, char delimiter);
 char	*str_linefeed(const char *src, size_t maxline, const char *delim);
 void	zbx_strarr_init(char ***arr);
 void	zbx_strarr_add(char ***arr, const char *entry);
@@ -1120,12 +1138,7 @@ void	zbx_setproctitle(const char *fmt, ...) __zbx_attr_format_printf(1, 2);
 #define ZBX_JAN_2038		2145916800
 #define ZBX_JAN_1970_IN_SEC	2208988800.0	/* 1970 - 1900 in seconds */
 
-#define ZBX_MAX_RECV_DATA_SIZE		(1 * ZBX_GIBIBYTE)
-#if defined(_WINDOWS)
-#define ZBX_MAX_RECV_LARGE_DATA_SIZE	(1 * ZBX_GIBIBYTE)
-#else
-#define ZBX_MAX_RECV_LARGE_DATA_SIZE	(__UINT64_C(16) * ZBX_GIBIBYTE)
-#endif
+#define ZBX_MAX_RECV_DATA_SIZE	(1 * ZBX_GIBIBYTE)
 
 /* max length of base64 data */
 #define ZBX_MAX_B64_LEN		(16 * ZBX_KIBIBYTE)
@@ -1135,6 +1148,7 @@ void		zbx_timespec(zbx_timespec_t *ts);
 double		zbx_current_time(void);
 void		zbx_get_time(struct tm *tm, long *milliseconds, zbx_timezone_t *tz);
 long		zbx_get_timezone_offset(time_t t, struct tm *tm);
+struct tm	*zbx_localtime(const time_t *time, const char *tz);
 int		zbx_utc_time(int year, int mon, int mday, int hour, int min, int sec, int *t);
 int		zbx_day_in_month(int year, int mon);
 zbx_uint64_t	zbx_get_duration_ms(const zbx_timespec_t *ts);
@@ -1235,8 +1249,8 @@ zbx_uint64_t	iprange_volume(const zbx_iprange_t *iprange);
 
 /* time related functions */
 char	*zbx_age2str(int age);
-char	*zbx_date2str(time_t date);
-char	*zbx_time2str(time_t time);
+char	*zbx_date2str(time_t date, const char *tz);
+char	*zbx_time2str(time_t time, const char *tz);
 
 #define ZBX_NULL2STR(str)	(NULL != str ? str : "(null)")
 #define ZBX_NULL2EMPTY_STR(str)	(NULL != (str) ? (str) : "")
@@ -1284,13 +1298,12 @@ int	zbx_cesu8_to_utf8(const char *cesu8, char **utf8);
 void	dos2unix(char *str);
 int	str2uint64(const char *str, const char *suffixes, zbx_uint64_t *value);
 double	str2double(const char *str);
-int	str2uint64whole(const char *str, zbx_uint64_t *value);
 
 /* time and memory size suffixes */
 #define ZBX_UNIT_SYMBOLS	"KMGTsmhdw"
 zbx_uint64_t	suffix2factor(char c);
 
-#if defined(_WINDOWS) || defined(__MINGW32__)
+#if defined(_WINDOWS)
 typedef struct __stat64	zbx_stat_t;
 int	__zbx_stat(const char *path, zbx_stat_t *buf);
 int	__zbx_open(const char *pathname, int flags);
@@ -1310,7 +1323,6 @@ int	zbx_get_file_time(const char *path, zbx_file_time_t *time);
 void	find_cr_lf_szbyte(const char *encoding, const char **cr, const char **lf, size_t *szbyte);
 int	zbx_read(int fd, char *buf, size_t count, const char *encoding);
 int	zbx_is_regular_file(const char *path);
-char	*zbx_fgets(char *buffer, int size, FILE *fp);
 
 int	MAIN_ZABBIX_ENTRY(int flags);
 
@@ -1329,7 +1341,6 @@ int	is_macro_char(unsigned char c);
 
 int	is_discovery_macro(const char *name);
 
-int	is_time_function(const char *func);
 int	is_snmp_type(unsigned char type);
 
 int	parse_key(const char **exp);
@@ -1418,17 +1429,20 @@ int	zbx_strcmp_natural(const char *s1, const char *s2);
 #define ZBX_TOKEN_SIMPLE_MACRO		0x00020
 #define ZBX_TOKEN_REFERENCE		0x00040
 #define ZBX_TOKEN_LLD_FUNC_MACRO	0x00080
+#define ZBX_TOKEN_EXPRESSION_MACRO	0x00100
 
 /* additional token flags */
-#define ZBX_TOKEN_TRIGGER	0x004000
-#define ZBX_TOKEN_NUMERIC	0x008000
-#define ZBX_TOKEN_JSON		0x010000
-#define ZBX_TOKEN_REGEXP	0x040000
-#define ZBX_TOKEN_XPATH		0x080000
-#define ZBX_TOKEN_REGEXP_OUTPUT	0x100000
-#define ZBX_TOKEN_PROMETHEUS	0x200000
-#define ZBX_TOKEN_JSONPATH	0x400000
-#define ZBX_TOKEN_STR_REPLACE	0x800000
+#define ZBX_TOKEN_TRIGGER	0x0004000
+#define ZBX_TOKEN_NUMERIC	0x0008000
+#define ZBX_TOKEN_JSON		0x0010000
+#define ZBX_TOKEN_XML		0x0020000
+#define ZBX_TOKEN_REGEXP	0x0040000
+#define ZBX_TOKEN_XPATH		0x0080000
+#define ZBX_TOKEN_REGEXP_OUTPUT	0x0100000
+#define ZBX_TOKEN_PROMETHEUS	0x0200000
+#define ZBX_TOKEN_JSONPATH	0x0400000
+#define ZBX_TOKEN_STR_REPLACE	0x0800000
+#define ZBX_TOKEN_STRING	0x1000000
 
 /* location of a substring */
 typedef struct
@@ -1447,6 +1461,13 @@ typedef struct
 }
 zbx_token_macro_t;
 
+/* data used by macros, ldd macros and objectid tokens */
+typedef struct
+{
+	zbx_strloc_t	expression;
+}
+zbx_token_expression_macro_t;
+
 /* data used by user macros */
 typedef struct
 {
@@ -1497,6 +1518,7 @@ typedef union
 	zbx_token_macro_t		objectid;
 	zbx_token_macro_t		macro;
 	zbx_token_macro_t		lld_macro;
+	zbx_token_expression_macro_t	expression_macro;
 	zbx_token_user_macro_t		user_macro;
 	zbx_token_func_macro_t		func_macro;
 	zbx_token_func_macro_t		lld_func_macro;
@@ -1517,12 +1539,11 @@ typedef struct
 }
 zbx_token_t;
 
-typedef enum
-{
-	ZBX_TOKEN_SEARCH_BASIC,
-	ZBX_TOKEN_SEARCH_REFERENCES
-}
-zbx_token_search_t;
+#define ZBX_TOKEN_SEARCH_BASIC			0x00
+#define ZBX_TOKEN_SEARCH_REFERENCES		0x01
+#define ZBX_TOKEN_SEARCH_EXPRESSION_MACRO	0x02
+
+typedef int zbx_token_search_t;
 
 int	zbx_token_find(const char *expression, int pos, zbx_token_t *token, zbx_token_search_t token_search);
 int	zbx_strmatch_condition(const char *value, const char *pattern, unsigned char op);
@@ -1559,6 +1580,7 @@ char	*zbx_expression_extract_constant(const char *src, const zbx_strloc_t *loc);
 #define ZBX_PREPROC_PROMETHEUS_TO_JSON		23
 #define ZBX_PREPROC_CSV_TO_JSON			24
 #define ZBX_PREPROC_STR_REPLACE			25
+#define ZBX_PREPROC_VALIDATE_NOT_SUPPORTED	26
 
 /* custom on fail actions */
 #define ZBX_PREPROC_FAIL_DEFAULT	0
@@ -1634,8 +1656,8 @@ zbx_uint32_t	zbx_variant_data_bin_get(const void *bin, void **data);
 int	zbx_validate_value_dbl(double value, int dbl_precision);
 
 void	zbx_update_env(double time_now);
-int	zbx_get_agent_item_nextcheck(zbx_uint64_t itemid, const char *delay, unsigned char state, int now,
-		int refresh_unsupported, int *nextcheck, char **error);
+int	zbx_get_agent_item_nextcheck(zbx_uint64_t itemid, const char *delay, int now,
+		int *nextcheck, char **error);
 
 #define ZBX_DATA_SESSION_TOKEN_SIZE	(MD5_DIGEST_SIZE * 2)
 char	*zbx_create_token(zbx_uint64_t seed);
@@ -1657,14 +1679,38 @@ int	zbx_str_extract(const char *text, size_t len, char **value);
 #define AUDIT_ACTION_EXECUTE	7
 #define AUDIT_RESOURCE_SCRIPT	25
 
-void	zbx_md5buf2str(const md5_byte_t *md5, char *str);
-int	zbx_hex2bin(const unsigned char *p_hex, unsigned char *buf, int buf_len);
+typedef enum
+{
+	ZBX_TIME_UNIT_UNKNOWN,
+	ZBX_TIME_UNIT_HOUR,
+	ZBX_TIME_UNIT_DAY,
+	ZBX_TIME_UNIT_WEEK,
+	ZBX_TIME_UNIT_MONTH,
+	ZBX_TIME_UNIT_YEAR,
+	ZBX_TIME_UNIT_COUNT
+}
+zbx_time_unit_t;
 
-int	zbx_xmlnode_to_json(void *xml_node, char **jstr);
-int	zbx_xml_to_json(char *xml_data, char **jstr, char **errmsg);
-#ifdef HAVE_LIBXML2
-int	zbx_open_xml(char *data, int options, int maxerrlen, void **xml_doc, void **root_node, char **errmsg);
-int	zbx_check_xml_memory(char *mem, int maxerrlen, char **errmsg);
-#endif
+void	zbx_tm_add(struct tm *tm, int multiplier, zbx_time_unit_t base);
+void	zbx_tm_sub(struct tm *tm, int multiplier, zbx_time_unit_t base);
+
+void	zbx_tm_round_up(struct tm *tm, zbx_time_unit_t base);
+void	zbx_tm_round_down(struct tm *tm, zbx_time_unit_t base);
+
+const char	*zbx_timespec_str(const zbx_timespec_t *ts);
+
+zbx_time_unit_t	zbx_tm_str_to_unit(const char *text);
+int	zbx_tm_parse_period(const char *period, size_t *len, int *multiplier, zbx_time_unit_t *base, char **error);
+
+typedef enum
+{
+	ZBX_FUNCTION_TYPE_UNKNOWN,
+	ZBX_FUNCTION_TYPE_HISTORY,
+	ZBX_FUNCTION_TYPE_TIMER,
+	ZBX_FUNCTION_TYPE_TRENDS
+}
+zbx_function_type_t;
+
+zbx_function_type_t	zbx_get_function_type(const char *func);
 
 #endif
