@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -85,6 +85,7 @@ struct	_DC_TRIGGER;
 #else
 #	define TRIGGER_COMMENTS_LEN	65535
 #endif
+#define TRIGGER_EVENT_NAME_LEN		2048
 #define TAG_NAME_LEN			255
 #define TAG_VALUE_LEN			255
 
@@ -175,7 +176,8 @@ struct	_DC_TRIGGER;
 #	define ITEM_HEADERS_LEN		65535
 #endif
 
-#define APPLICATION_NAME_LEN		255
+#define ITEM_PARAMETER_NAME_LEN		255
+#define ITEM_PARAMETER_VALUE_LEN	2048
 
 #define HISTORY_STR_VALUE_LEN		255
 #define HISTORY_TEXT_VALUE_LEN		65535
@@ -259,14 +261,6 @@ struct	_DC_TRIGGER;
 
 #define ZBX_DB_MAX_ID	(zbx_uint64_t)__UINT64_C(0x7fffffffffffffff)
 
-#ifdef HAVE_MYSQL
-#	define ZBX_SQL_SORT_ASC(field)	field " asc"
-#	define ZBX_SQL_SORT_DESC(field)	field " desc"
-#else
-#	define ZBX_SQL_SORT_ASC(field)	field " asc nulls first"
-#	define ZBX_SQL_SORT_DESC(field)	field " desc nulls last"
-#endif
-
 typedef struct
 {
 	zbx_uint64_t	druleid;
@@ -322,6 +316,7 @@ typedef struct
 	char		*comments;
 	char		*correlation_tag;
 	char		*opdata;
+	char		*event_name;
 	unsigned char	value;
 	unsigned char	priority;
 	unsigned char	type;
@@ -507,8 +502,9 @@ const ZBX_FIELD	*DBget_field(const ZBX_TABLE *table, const char *fieldname);
 #define DBget_maxid(table)	DBget_maxid_num(table, 1)
 zbx_uint64_t	DBget_maxid_num(const char *tablename, int num);
 
+void	DBcheck_capabilities(void);
+
 #ifdef HAVE_POSTGRESQL
-void	zbx_db_check_tsdb_capabilities(void);
 char	*zbx_db_get_schema_esc(void);
 #endif
 
@@ -753,7 +749,6 @@ typedef struct
 	zbx_uint64_t	lastlogsize;
 	unsigned char	state;
 	int		mtime;
-	int		lastclock;
 	const char	*error;
 
 	zbx_uint64_t	flags;
@@ -762,11 +757,9 @@ typedef struct
 #define ZBX_FLAGS_ITEM_DIFF_UPDATE_ERROR		__UINT64_C(0x0002)
 #define ZBX_FLAGS_ITEM_DIFF_UPDATE_MTIME		__UINT64_C(0x0004)
 #define ZBX_FLAGS_ITEM_DIFF_UPDATE_LASTLOGSIZE		__UINT64_C(0x0008)
-#define ZBX_FLAGS_ITEM_DIFF_UPDATE_LASTCLOCK		__UINT64_C(0x1000)
 #define ZBX_FLAGS_ITEM_DIFF_UPDATE_DB			\
 	(ZBX_FLAGS_ITEM_DIFF_UPDATE_STATE | ZBX_FLAGS_ITEM_DIFF_UPDATE_ERROR |\
 	ZBX_FLAGS_ITEM_DIFF_UPDATE_MTIME | ZBX_FLAGS_ITEM_DIFF_UPDATE_LASTLOGSIZE)
-#define ZBX_FLAGS_ITEM_DIFF_UPDATE	(ZBX_FLAGS_ITEM_DIFF_UPDATE_DB | ZBX_FLAGS_ITEM_DIFF_UPDATE_LASTCLOCK)
 }
 zbx_item_diff_t;
 
@@ -826,5 +819,58 @@ int	zbx_db_mock_field_append(zbx_db_mock_field_t *field, const char *text);
 
 int	zbx_db_check_instanceid(void);
 
-void	zbx_recalc_history_time_period(int *ts_from);
+/* tags */
+typedef struct
+{
+	zbx_uint64_t	tagid;
+	char		*tag;
+	char		*value;
+#define ZBX_FLAG_DB_TAG_UPDATE_TAG		__UINT64_C(0x00000001)
+#define ZBX_FLAG_DB_TAG_UPDATE_VALUE		__UINT64_C(0x00000002)
+#define ZBX_FLAG_DB_TAG_REMOVE			__UINT64_C(0x80000000)
+#define ZBX_FLAG_DB_TAG_UPDATE			(ZBX_FLAG_DB_TAG_UPDATE_TAG | ZBX_FLAG_DB_TAG_UPDATE_VALUE)
+	zbx_uint64_t	flags;
+}
+zbx_db_tag_t;
+
+void	zbx_db_tag_free(zbx_db_tag_t *tag);
+int	zbx_db_tag_compare_func(const void *d1, const void *d2);
+
+ZBX_PTR_VECTOR_DECL(db_tag_ptr, zbx_db_tag_t *);
+
+typedef enum
+{
+	ZBX_LLD_OVERRIDE_OP_OBJECT_ITEM = 0,
+	ZBX_LLD_OVERRIDE_OP_OBJECT_TRIGGER,
+	ZBX_LLD_OVERRIDE_OP_OBJECT_GRAPH,
+	ZBX_LLD_OVERRIDE_OP_OBJECT_HOST
+}
+zbx_lld_override_op_object_t;
+
+typedef struct
+{
+	zbx_uint64_t		override_operationid;
+	zbx_uint64_t		overrideid;
+	char			*value;
+	char			*delay;
+	char			*history;
+	char			*trends;
+	zbx_vector_db_tag_ptr_t	tags;
+	zbx_vector_uint64_t	templateids;
+	unsigned char		operationtype;
+	unsigned char		operator;
+	unsigned char		status;
+	unsigned char		severity;
+	unsigned char		inventory_mode;
+	unsigned char		discover;
+}
+zbx_lld_override_operation_t;
+
+void	zbx_lld_override_operation_free(zbx_lld_override_operation_t *override_operation);
+
+void	zbx_load_lld_override_operations(const zbx_vector_uint64_t *overrideids, char **sql, size_t *sql_alloc,
+		zbx_vector_ptr_t *ops);
+
+
+
 #endif
