@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -50,10 +50,6 @@
 
 #define ZBX_SNMPTRAP_LOGGING_ENABLED	1
 
-#define ZBX_IPC_SERVICE_CONFIG		"config"
-#define ZBX_IPC_CONFIG_RELOAD_REQUEST	1
-#define ZBX_IPC_CONFIG_RELOAD_RESPONSE	2
-
 extern int	CONFIG_TIMEOUT;
 
 extern zbx_uint64_t	CONFIG_CONF_CACHE_SIZE;
@@ -127,6 +123,7 @@ typedef struct
 	int		jmx_errors_from;
 	unsigned char	jmx_available;
 	int		jmx_disable_until;
+	char		inventory_mode;
 	unsigned char	status;
 	unsigned char	tls_connect;
 	unsigned char	tls_accept;
@@ -159,7 +156,10 @@ typedef struct
 	unsigned char		flags;
 	unsigned char		snmpv3_authprotocol;
 	unsigned char		snmpv3_privprotocol;
+	unsigned char		inventory_link;
 	unsigned char		status;
+	unsigned char		history;
+	unsigned char		trends;
 	unsigned char		follow_redirects;
 	unsigned char		post_type;
 	unsigned char		retrieve_mode;
@@ -171,8 +171,8 @@ typedef struct
 	char			key_orig[ITEM_KEY_LEN * ZBX_MAX_BYTES_IN_UTF8_CHAR + 1], *key;
 	char			*units;
 	char			*delay;
-	int			nextcheck;
-	int			lastclock;
+	int			history_sec;
+	int			trends_sec;
 	int			mtime;
 	char			trapper_hosts[ITEM_TRAPPER_HOSTS_LEN_MAX];
 	char			logtimefmt[ITEM_LOGTIMEFMT_LEN_MAX];
@@ -199,90 +199,11 @@ typedef struct
 	char			ssl_cert_file_orig[ITEM_SSL_CERT_FILE_LEN_MAX], *ssl_cert_file;
 	char			ssl_key_file_orig[ITEM_SSL_KEY_FILE_LEN_MAX], *ssl_key_file;
 	char			ssl_key_password_orig[ITEM_SSL_KEY_PASSWORD_LEN_MAX], *ssl_key_password;
+	char			*script_params;
 	char			*error;
 }
 DC_ITEM;
 
-typedef struct
-{
-	zbx_uint64_t	hostid;
-	zbx_uint64_t	proxy_hostid;
-	char		host[HOST_HOST_LEN_MAX];
-	char		name[HOST_NAME_LEN * ZBX_MAX_BYTES_IN_UTF8_CHAR + 1];
-	signed char	inventory_mode;
-	unsigned char	status;
-}
-zbx_history_sync_host_t;
-
-typedef struct
-{
-	zbx_history_sync_host_t	host;
-	zbx_uint64_t		itemid;
-	zbx_uint64_t		lastlogsize;
-	zbx_uint64_t		valuemapid;
-	char			key_orig[ITEM_KEY_LEN * ZBX_MAX_BYTES_IN_UTF8_CHAR + 1];
-	char			*units;
-	char			*error;
-	int			mtime;
-	int			history_sec;
-	int			trends_sec;
-	unsigned char		type;
-	unsigned char		value_type;
-	unsigned char		state;
-	unsigned char		inventory_link;
-	unsigned char		status;
-	unsigned char		history;
-	unsigned char		trends;
-}
-zbx_history_sync_item_t;
-
-typedef struct
-{
-	zbx_uint64_t	hostid;
-	zbx_uint64_t	proxy_hostid;
-	char		host[HOST_HOST_LEN_MAX];
-	char		name[HOST_NAME_LEN * ZBX_MAX_BYTES_IN_UTF8_CHAR + 1];
-	unsigned char	maintenance_status;
-	unsigned char	maintenance_type;
-	int		maintenance_from;
-	unsigned char	status;
-	unsigned char	tls_accept;
-#if defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
-	char		tls_issuer[HOST_TLS_ISSUER_LEN_MAX];
-	char		tls_subject[HOST_TLS_SUBJECT_LEN_MAX];
-	char		tls_psk_identity[HOST_TLS_PSK_IDENTITY_LEN_MAX];
-	char		tls_psk[HOST_TLS_PSK_LEN_MAX];
-#endif
-}
-zbx_history_recv_host_t;
-
-typedef struct
-{
-	zbx_history_recv_host_t	host;
-	DC_INTERFACE		interface;
-	zbx_uint64_t		itemid;
-	unsigned char		value_type;
-	unsigned char		state;
-	unsigned char		flags;
-	unsigned char		type;
-	unsigned char		status;
-	unsigned char		allow_traps;
-	char			key_orig[ITEM_KEY_LEN * ZBX_MAX_BYTES_IN_UTF8_CHAR + 1], *key;
-	char			trapper_hosts[ITEM_TRAPPER_HOSTS_LEN_MAX];
-	char			logtimefmt[ITEM_LOGTIMEFMT_LEN_MAX];
-}
-zbx_history_recv_item_t;
-
-typedef struct
-{
-	zbx_uint64_t	itemid;
-	zbx_uint64_t	proxy_hostid;
-	const char	*host;
-	const char	*key_orig;
-	unsigned char	value_type;
-}
-DC_EVALUATE_ITEM;
-
 typedef struct
 {
 	zbx_uint64_t	functionid;
@@ -326,6 +247,7 @@ typedef struct _DC_TRIGGER
 	char			*new_error;
 	char			*correlation_tag;
 	char			*opdata;
+	char			*event_name;
 	zbx_timespec_t		timespec;
 	int			lastchange;
 	unsigned char		topoindex;
@@ -448,9 +370,9 @@ typedef struct
 	char		**severity_name;
 	zbx_uint64_t	discovery_groupid;
 	int		default_inventory_mode;
-	int		refresh_unsupported;
 	unsigned char	snmptrap_logging;
 	unsigned char	autoreg_tls_accept;
+	char		*default_timezone;
 
 	/* database configuration data for ZBX_CONFIG_DB_EXTENSION_* extensions */
 	zbx_config_db_t	db;
@@ -463,11 +385,11 @@ zbx_config_t;
 #define ZBX_CONFIG_FLAGS_SEVERITY_NAME			__UINT64_C(0x0000000000000001)
 #define ZBX_CONFIG_FLAGS_DISCOVERY_GROUPID		__UINT64_C(0x0000000000000002)
 #define ZBX_CONFIG_FLAGS_DEFAULT_INVENTORY_MODE		__UINT64_C(0x0000000000000004)
-#define ZBX_CONFIG_FLAGS_REFRESH_UNSUPPORTED		__UINT64_C(0x0000000000000008)
 #define ZBX_CONFIG_FLAGS_SNMPTRAP_LOGGING		__UINT64_C(0x0000000000000010)
 #define ZBX_CONFIG_FLAGS_HOUSEKEEPER			__UINT64_C(0x0000000000000020)
 #define ZBX_CONFIG_FLAGS_DB_EXTENSION			__UINT64_C(0x0000000000000040)
 #define ZBX_CONFIG_FLAGS_AUTOREG_TLS_ACCEPT		__UINT64_C(0x0000000000000080)
+#define ZBX_CONFIG_FLAGS_DEFAULT_TIMEZONE		__UINT64_C(0x0000000000000100)
 
 /* possible values for database extensions (if flag ZBX_CONFIG_FLAGS_DB_EXTENSION set) */
 #define ZBX_CONFIG_DB_EXTENSION_TIMESCALE		"timescaledb"
@@ -731,21 +653,29 @@ zbx_uint64_t	DCget_nextid(const char *table_name, int num);
 #define ZBX_DBSYNC_INIT		0
 /* update sync, get changed data */
 #define ZBX_DBSYNC_UPDATE	1
+#define ZBX_SYNC_SECRETS	2
 
-#define ZBX_ITEM_GET_INTERFACE		0x0001
-#define ZBX_ITEM_GET_HOST		0x0002
-#define ZBX_ITEM_GET_HOSTNAME		0x0004
-#define ZBX_ITEM_GET_HOSTINFO		0x0008
-#define ZBX_ITEM_GET_TRAPPER		0x0010
+#define ZBX_ITEM_GET_MISC		0x001
+#define ZBX_ITEM_GET_DELAY		0x002
+#define ZBX_ITEM_GET_EMPTY_ERROR	0x004
+#define ZBX_ITEM_GET_NUM		0x008
+#define ZBX_ITEM_GET_EMPTY_UNITS	0x010
+#define ZBX_ITEM_GET_LOGTIMEFMT		0x020
+#define ZBX_ITEM_GET_POLLINFO		0x040
+#define ZBX_ITEM_GET_INTERFACE		0x080
+#define ZBX_ITEM_GET_HOSTNAME		0x100
+#define ZBX_ITEM_GET_HOSTINFO		0x200
+#define ZBX_ITEM_GET_MAINTENANCE	0x400
+#define ZBX_ITEM_GET_INVENTORY		0x800
 
-#define ZBX_ITEM_GET_DEFAULT		((unsigned int)~0)
+#define ZBX_ITEM_GET_ALL		(~(unsigned int)0)
 
-#define ZBX_ITEM_GET_SYNC		0
-#define ZBX_ITEM_GET_SYNC_EXPORT	(ZBX_ITEM_GET_HOSTNAME)
+#define ZBX_ITEM_GET_SYNC		(ZBX_ITEM_GET_INVENTORY|ZBX_ITEM_GET_NUM)
+#define ZBX_ITEM_GET_SYNC_EXPORT	(ZBX_ITEM_GET_INVENTORY|ZBX_ITEM_GET_NUM|ZBX_ITEM_GET_HOSTNAME)
 
-#define ZBX_ITEM_GET_PROCESS		0
+#define ZBX_ITEM_GET_PROCESS		(ZBX_ITEM_GET_MAINTENANCE|ZBX_ITEM_GET_MISC|ZBX_ITEM_GET_LOGTIMEFMT)
 
-void	DCsync_configuration(unsigned char mode);
+void	DCsync_configuration(unsigned char mode, const struct zbx_json_parse *jp_kvs_paths);
 int	init_configuration_cache(char **error);
 void	free_configuration_cache(void);
 
@@ -757,19 +687,8 @@ int	DCconfig_get_hostid_by_name(const char *host, zbx_uint64_t *hostid);
 void	DCconfig_get_hosts_by_itemids(DC_HOST *hosts, const zbx_uint64_t *itemids, int *errcodes, size_t num);
 void	DCconfig_get_items_by_keys(DC_ITEM *items, zbx_host_key_t *keys, int *errcodes, size_t num);
 void	DCconfig_get_items_by_itemids(DC_ITEM *items, const zbx_uint64_t *itemids, int *errcodes, size_t num);
-void	zbx_dc_config_history_sync_get_items_by_itemids(zbx_history_sync_item_t *items, const zbx_uint64_t *itemids,
-		int *errcodes, size_t num, unsigned int mode);
-void	zbx_dc_config_history_sync_get_functions_by_functionids(DC_FUNCTION *functions, zbx_uint64_t *functionids,
-		int *errcodes, size_t num);
-void	zbx_dc_config_history_sync_get_triggers_by_itemids(zbx_hashset_t *trigger_info, zbx_vector_ptr_t *trigger_order,
-		const zbx_uint64_t *itemids, const zbx_timespec_t *timespecs, int itemids_num);
-void	zbx_dc_config_clean_history_sync_items(zbx_history_sync_item_t *items, int *errcodes, size_t num);
-void	zbx_dc_config_history_sync_unset_existing_itemids(zbx_vector_uint64_t *itemids);
-
-void	zbx_dc_config_history_recv_get_items_by_keys(zbx_history_recv_item_t *items, const zbx_host_key_t *keys,
-		int *errcodes, size_t num);
-void	zbx_dc_config_history_recv_get_items_by_itemids(zbx_history_recv_item_t *items, const zbx_uint64_t *itemids,
-		int *errcodes, size_t num, unsigned int mode);
+void	DCconfig_get_items_by_itemids_partial(DC_ITEM *items, const zbx_uint64_t *itemids, int *errcodes, size_t num,
+		unsigned int mode);
 void	DCconfig_get_preprocessable_items(zbx_hashset_t *items, int *timestamp);
 void	DCconfig_get_functions_by_functionids(DC_FUNCTION *functions,
 		zbx_uint64_t *functionids, int *errcodes, size_t num);
@@ -779,8 +698,8 @@ int	DCconfig_lock_triggers_by_history_items(zbx_vector_ptr_t *history_items, zbx
 void	DCconfig_lock_triggers_by_triggerids(zbx_vector_uint64_t *triggerids_in, zbx_vector_uint64_t *triggerids_out);
 void	DCconfig_unlock_triggers(const zbx_vector_uint64_t *triggerids);
 void	DCconfig_unlock_all_triggers(void);
-int	DCconfig_trigger_exists(zbx_uint64_t triggerid);
-
+void	DCconfig_get_triggers_by_itemids(zbx_hashset_t *trigger_info, zbx_vector_ptr_t *trigger_order,
+		const zbx_uint64_t *itemids, const zbx_timespec_t *timespecs, int itemids_num);
 void	DCfree_triggers(zbx_vector_ptr_t *triggers);
 void	DCconfig_update_interface_snmp_stats(zbx_uint64_t interfaceid, int max_snmp_succeed, int min_snmp_fail);
 int	DCconfig_get_suggested_snmp_vars(zbx_uint64_t interfaceid, int *bulk);
@@ -804,9 +723,9 @@ size_t	DCconfig_get_snmp_items_by_interfaceid(zbx_uint64_t interfaceid, DC_ITEM
 #define ZBX_HK_TRENDS_MIN	SEC_PER_DAY
 #define ZBX_HK_PERIOD_MAX	(25 * SEC_PER_YEAR)
 
-void	DCrequeue_items(const zbx_uint64_t *itemids, const unsigned char *states, const int *lastclocks,
+void	DCrequeue_items(const zbx_uint64_t *itemids, const int *lastclocks,
 		const int *errcodes, size_t num);
-void	DCpoller_requeue_items(const zbx_uint64_t *itemids, const unsigned char *states, const int *lastclocks,
+void	DCpoller_requeue_items(const zbx_uint64_t *itemids, const int *lastclocks,
 		const int *errcodes, size_t num, unsigned char poller_type, int *nextcheck);
 void	zbx_dc_requeue_unreachable_items(zbx_uint64_t *itemids, size_t itemids_num);
 int	DCconfig_activate_host(DC_ITEM *item);
@@ -850,6 +769,7 @@ void	DCget_autoregistration_psk(char *psk_identity_buf, size_t psk_identity_buf_
 
 #define ZBX_MACRO_VALUE_TEXT	0
 #define ZBX_MACRO_VALUE_SECRET	1
+#define ZBX_MACRO_VALUE_VAULT	2
 
 #define ZBX_MACRO_SECRET_MASK	"******"
 
@@ -899,14 +819,13 @@ unsigned int	DCget_internal_action_count(void);
 #define ZBX_DISCOVERY_GROUPID_UNDEFINED	0
 void	zbx_config_get(zbx_config_t *cfg, zbx_uint64_t flags);
 void	zbx_config_clean(zbx_config_t *cfg);
-void	zbx_config_get_hk_mode(unsigned char *history_mode, unsigned char *trends_mode);
 
 int	DCset_hosts_availability(zbx_vector_ptr_t *availabilities);
 
 int	DCreset_hosts_availability(zbx_vector_ptr_t *hosts);
 void	DCupdate_hosts_availability(void);
 
-void	zbx_dc_config_history_sync_get_actions_eval(zbx_vector_ptr_t *actions, unsigned char opflags);
+void	zbx_dc_get_actions_eval(zbx_vector_ptr_t *actions, unsigned char opflags);
 
 int	DCget_hosts_availability(zbx_vector_ptr_t *hosts, int *ts);
 void	DCtouch_hosts_availability(const zbx_vector_uint64_t *hostids);
@@ -983,8 +902,7 @@ typedef struct
 }
 zbx_agent_value_t;
 
-void	zbx_dc_items_update_nextcheck(zbx_history_recv_item_t *items, zbx_agent_value_t *values, int *errcodes,
-		size_t values_num);
+void	zbx_dc_items_update_nextcheck(DC_ITEM *items, zbx_agent_value_t *values, int *errcodes, size_t values_num);
 int	zbx_dc_get_host_interfaces(zbx_uint64_t hostid, DC_INTERFACE2 **interfaces, int *n);
 
 void	zbx_dc_update_proxy(zbx_proxy_diff_t *diff);
@@ -1003,11 +921,6 @@ void	zbx_dc_get_trigger_dependencies(const zbx_vector_uint64_t *triggerids, zbx_
 
 void	zbx_dc_reschedule_items(const zbx_vector_uint64_t *itemids, int nextcheck, zbx_uint64_t *proxy_hostids);
 
-void	zbx_dc_get_timer_triggerids(zbx_vector_uint64_t *triggerids, int now, int limit);
-void	zbx_dc_get_timer_triggers_by_triggerids(zbx_hashset_t *trigger_info, zbx_vector_ptr_t *trigger_order,
-		const zbx_vector_uint64_t *triggerids, const zbx_timespec_t *ts);
-void	zbx_dc_clear_timer_queue(void);
-
 /* data session support */
 
 typedef struct
@@ -1069,8 +982,6 @@ void	zbx_dc_maintenance_reset_update_flag(int timer);
 int	zbx_dc_maintenance_check_update_flag(int timer);
 int	zbx_dc_maintenance_check_update_flags(void);
 
-int	zbx_dc_maintenance_has_tags(void);
-
 typedef struct
 {
 	char	*lld_macro;
@@ -1084,14 +995,14 @@ int	zbx_lld_macro_value_by_name(const struct zbx_json_parse *jp_row, const zbx_v
 		const char *macro, char **value);
 int	zbx_lld_macro_paths_compare(const void *d1, const void *d2);
 
-void	zbx_dc_config_history_sync_get_item_tags_by_functionids(const zbx_uint64_t *functionids,
-		size_t functionids_num, zbx_vector_ptr_t *item_tags);
-void	zbx_get_item_tags(zbx_uint64_t itemid, zbx_vector_ptr_t *item_tags);
+void	zbx_dc_get_item_tags_by_functionids(const zbx_uint64_t *functionids, size_t functionids_num,
+		zbx_vector_ptr_t *item_tags);
 
 unsigned char	zbx_dc_set_macro_env(unsigned char env);
 
 const char	*zbx_dc_get_instanceid(void);
 
+char	*zbx_dc_expand_user_macros(const char *text, zbx_uint64_t hostid);
 char	*zbx_dc_expand_user_macros_in_func_params(const char *params, zbx_uint64_t hostid);
 
 /* diagnostic data */
@@ -1099,6 +1010,30 @@ void	zbx_hc_get_diag_stats(zbx_uint64_t *items_num, zbx_uint64_t *values_num);
 void	zbx_hc_get_mem_stats(zbx_mem_stats_t *data, zbx_mem_stats_t *index);
 void	zbx_hc_get_items(zbx_vector_uint64_pair_t *items);
 
+typedef struct
+{
+	zbx_uint64_t		objectid;
+	zbx_uint64_t		triggerid;
+	zbx_function_type_t	type;
+	zbx_time_unit_t		trend_base;
+	unsigned char		lock;		/* 1 if the timer has locked trigger, 0 otherwise */
+	int			revision;	/* function revision */
+	zbx_timespec_t		eval_ts;	/* the history time for which trigger must be recalculated */
+	zbx_timespec_t		exec_ts;	/* real time when the timer must be executed */
+	const char		*parameter;	/* function parameters (for trend functions) */
+}
+zbx_trigger_timer_t;
+
+void	zbx_dc_reschedule_trigger_timers(zbx_vector_ptr_t *timers, int now);
+void	zbx_dc_get_trigger_timers(zbx_vector_ptr_t *timers, int now, int soft_limit, int hard_limit);
+void	zbx_dc_clear_timer_queue(zbx_vector_ptr_t *timers);
+void	zbx_dc_get_triggers_by_timers(zbx_hashset_t *trigger_info, zbx_vector_ptr_t *trigger_order,
+		const zbx_vector_ptr_t *timers);
+void	zbx_dc_free_timers(zbx_vector_ptr_t *timers);
+
+int	zbx_db_trigger_queue_locked(void);
+void	zbx_db_trigger_queue_unlock(void);
+
 int	zbx_hc_check_proxy(zbx_uint64_t proxyid);
 
 #endif
