@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@ typedef enum
 #ifdef HAVE_VMINFO_T_UPDATES
 	ZBX_MUTEX_KSTAT,
 #endif
+	ZBX_MUTEX_MODBUS,
 	/* NOTE: Do not forget to sync changes here with mutex names in diag_add_locks_info()! */
 	ZBX_MUTEX_COUNT
 }
@@ -55,7 +56,6 @@ zbx_mutex_name_t;
 typedef enum
 {
 	ZBX_RWLOCK_CONFIG = 0,
-	ZBX_RWLOCK_CONFIG_HISTORY,
 	ZBX_RWLOCK_VALUECACHE,
 	ZBX_RWLOCK_COUNT,
 }
