@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,12 +24,12 @@
 #define ZBX_STR(str)	ZBX_STR2(str)
 
 #define APPLICATION_NAME	"Zabbix Agent"
-#define ZABBIX_REVDATE		"30 November 2023"
+#define ZABBIX_REVDATE		"28 June 2021"
 #define ZABBIX_VERSION_MAJOR	5
-#define ZABBIX_VERSION_MINOR	0
-#define ZABBIX_VERSION_PATCH	40
+#define ZABBIX_VERSION_MINOR	2
+#define ZABBIX_VERSION_PATCH	7
 #ifndef ZABBIX_VERSION_REVISION
-#	define ZABBIX_VERSION_REVISION	8856587278e
+#	define ZABBIX_VERSION_REVISION	91e8333180
 #endif
 #ifdef _WINDOWS
 #	ifndef ZABBIX_VERSION_RC_NUM
