@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,11 +27,27 @@ void	zbx_http_url_encode(const char *source, char **result);
 int	zbx_http_url_decode(const char *source, char **result);
 
 #ifdef HAVE_LIBCURL
+
+typedef struct
+{
+	char	*data;
+	size_t	allocated;
+	size_t	offset;
+}
+zbx_http_response_t;
+
+size_t	zbx_curl_write_cb(void *ptr, size_t size, size_t nmemb, void *userdata);
+size_t	zbx_curl_ignore_cb(void *ptr, size_t size, size_t nmemb, void *userdata);
+
+int	zbx_http_prepare_callbacks(CURL *easyhandle, zbx_http_response_t *header,
+		zbx_http_response_t *body, void *header_cb, void *body_cb, char *errbuf, char **error);
 int	zbx_http_prepare_ssl(CURL *easyhandle, const char *ssl_cert_file, const char *ssl_key_file,
 		const char *ssl_key_password, unsigned char verify_peer, unsigned char verify_host, char **error);
 int	zbx_http_prepare_auth(CURL *easyhandle, unsigned char authtype, const char *username, const char *password,
 		char **error);
-char	*zbx_http_get_header(char **headers);
+char	*zbx_http_parse_header(char **headers);
+
+int	zbx_http_get(const char *url, const char *header, long timeout, char **out, long *response_code, char **error);
 #endif
 
 #endif
