@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,9 +38,12 @@
 #	endif
 #endif
 
-#if defined(_WINDOWS) || defined(__MINGW32__)
+#if defined(_WINDOWS)
 #	define zbx_open(pathname, flags)	__zbx_open(pathname, flags | O_BINARY)
 #	define PATH_SEPARATOR	'\\'
+#elif defined(__MINGW32__)
+#	define zbx_open(pathname, flags)	open(pathname, flags | O_BINARY)
+#	define PATH_SEPARATOR	'\\'
 #else
 #	define zbx_open(pathname, flags)	open(pathname, flags)
 #	define PATH_SEPARATOR	'/'
@@ -49,6 +52,9 @@
 #if defined(_WINDOWS)
 #	include <strsafe.h>
 
+#	define zbx_stat(path, buf)		__zbx_stat(path, buf)
+#	define zbx_fstat(fd, buf)		_fstat64(fd, buf)
+
 #	ifndef __UINT64_C
 #		define __UINT64_C(x)	x
 #	endif
@@ -79,6 +85,9 @@ typedef uint32_t		zbx_uint32_t;
 
 #	define strcasecmp	lstrcmpiA
 
+typedef __int64	zbx_offset_t;
+#	define zbx_lseek(fd, offset, whence)	_lseeki64(fd, (zbx_offset_t)(offset), whence)
+
 #	if defined(__INT_MAX__) && __INT_MAX__ == 2147483647
 typedef int	ssize_t;
 #	else
@@ -86,6 +95,9 @@ typedef long	ssize_t;
 #	endif
 
 #else	/* _WINDOWS */
+#	define zbx_stat(path, buf)		stat(path, buf)
+#	define zbx_fstat(fd, buf)		fstat(fd, buf)
+
 #	ifndef __UINT64_C
 #		ifdef UINT64_C
 #			define __UINT64_C(c)	(UINT64_C(c))
@@ -150,30 +162,10 @@ typedef long	ssize_t;
 
 typedef uint32_t	zbx_uint32_t;
 
-#endif	/* _WINDOWS */
-
-#if defined(_WINDOWS)
-#	define zbx_stat(path, buf)		__zbx_stat(path, buf)
-#	define zbx_fstat(fd, buf)		_fstat64(fd, buf)
-
-typedef __int64	zbx_offset_t;
-#	define zbx_lseek(fd, offset, whence)	_lseeki64(fd, (zbx_offset_t)(offset), whence)
-
-#elif defined(__MINGW32__)
-#	define zbx_stat(path, buf)		__zbx_stat(path, buf)
-#	define zbx_fstat(fd, buf)		_fstat64(fd, buf)
-
-typedef off64_t	zbx_offset_t;
-#	define zbx_lseek(fd, offset, whence)	lseek64(fd, (zbx_offset_t)(offset), whence)
-
-#else
-#	define zbx_stat(path, buf)		stat(path, buf)
-#	define zbx_fstat(fd, buf)		fstat(fd, buf)
-
 typedef off_t	zbx_offset_t;
 #	define zbx_lseek(fd, offset, whence)	lseek(fd, (zbx_offset_t)(offset), whence)
 
-#endif
+#endif	/* _WINDOWS */
 
 #define ZBX_FS_DBL		"%lf"
 #define ZBX_FS_DBL_EXT(p)	"%." #p "lf"
@@ -222,4 +214,8 @@ zbx_uint128_t;
 /* macro to test if a signed value has been assigned to unsigned type (char, short, int, long long) */
 #define ZBX_IS_TOP_BIT_SET(x)	(0 != ((__UINT64_C(1) << ((sizeof(x) << 3) - 1)) & (x)))
 
+#if defined(_WINDOWS)
+	#define localtime_r(x, y)	localtime_s(y, x)
+#endif
+
 #endif
