@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,15 +29,15 @@ import (
 
 const (
 	APPLICATION_NAME        = "Zabbix Agent"
-	ZABBIX_REVDATE          = "30 November 2023"
+	ZABBIX_REVDATE          = "28 June 2021"
 	ZABBIX_VERSION_MAJOR    = 5
-	ZABBIX_VERSION_MINOR    = 0
-	ZABBIX_VERSION_PATCH    = 40
+	ZABBIX_VERSION_MINOR    = 2
+	ZABBIX_VERSION_PATCH    = 7
 	ZABBIX_VERSION_RC       = ""
 	ZABBIX_VERSION_RC_NUM   = "2400"
-	ZABBIX_VERSION_REVISION = "8856587278e"
-	copyrightMessage        = "Copyright (C) 2023 Zabbix SIA\n" +
-		"License GPLv2+: GNU GPL version 2 or later <https://www.gnu.org/licenses/>.\n" +
+	ZABBIX_VERSION_REVISION = "91e8333180"
+	copyrightMessage        = "Copyright (C) 2021 Zabbix SIA\n" +
+		"License GPLv2+: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>.\n" +
 		"This is free software: you are free to change and redistribute it according to\n" +
 		"the license. There is NO WARRANTY, to the extent permitted by law."
 )
@@ -98,8 +98,28 @@ func Revision() string {
 	return ZABBIX_VERSION_REVISION
 }
 
+func copyrightMessageMQTT() string {
+	return "\nWe use the library Eclipse Paho (eclipse/paho.mqtt.golang), which is\n" +
+		"distributed under the terms of the Eclipse Distribution License 1.0 (The 3-Clause BSD License)\n" +
+		"available at https://www.eclipse.org/org/documents/edl-v10.php\n"
+}
+
+func copyrightMessageModbus() string {
+	return "\nWe use the library go-modbus (goburrow/modbus), which is\n" +
+		"distributed under the terms of the 3-Clause BSD License\n" +
+		"available at https://github.com/goburrow/modbus/blob/master/LICENSE\n"
+}
+
 func CopyrightMessage() string {
-	return copyrightMessage + tls.CopyrightMessage()
+	msg := copyrightMessage
+	tlsMsg := tls.CopyrightMessage()
+	if tlsMsg == "" {
+		msg += "\n"
+	} else {
+		msg += tlsMsg
+	}
+
+	return msg + copyrightMessageModbus() + copyrightMessageMQTT()
 }
 
 func CompileDate() string {
