@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -51,7 +51,6 @@ typedef struct
 	size_t			headers_in_alloc;
 	size_t			headers_in_offset;
 	unsigned char		custom_header;
-	size_t			headers_sz;
 }
 zbx_es_httprequest_t;
 
@@ -118,16 +117,9 @@ static duk_ret_t	es_httprequest_dtor(duk_context *ctx)
 	zbx_es_httprequest_t	*request;
 
 	duk_get_prop_string(ctx, 0, "\xff""\xff""d");
-
-	if (NULL != (request = (zbx_es_httprequest_t *)duk_to_pointer(ctx, -1)))
+	request = (zbx_es_httprequest_t *)duk_to_pointer(ctx, -1);
+	if (NULL != request)
 	{
-		zbx_es_env_t	*env;
-
-		if (NULL == (env = zbx_es_get_env(ctx)))
-			return duk_error(ctx, DUK_RET_TYPE_ERROR, "cannot access internal environment");
-
-		env->http_req_objects--;
-
 		if (NULL != request->headers)
 			curl_slist_free_all(request->headers);
 		if (NULL != request->handle)
@@ -152,7 +144,6 @@ static duk_ret_t	es_httprequest_dtor(duk_context *ctx)
  ******************************************************************************/
 static duk_ret_t	es_httprequest_ctor(duk_context *ctx)
 {
-#define MAX_HTTPREQUEST_OBJECT_COUNT	10
 	zbx_es_httprequest_t	*request;
 	CURLcode		err;
 	zbx_es_env_t		*env;
@@ -161,11 +152,13 @@ static duk_ret_t	es_httprequest_ctor(duk_context *ctx)
 	if (!duk_is_constructor_call(ctx))
 		return DUK_RET_TYPE_ERROR;
 
-	if (NULL == (env = zbx_es_get_env(ctx)))
+	duk_push_global_stash(ctx);
+
+	if (1 != duk_get_prop_string(ctx, -1, "\xff""\xff""zbx_env"))
 		return duk_error(ctx, DUK_RET_TYPE_ERROR, "cannot access internal environment");
 
-	if (MAX_HTTPREQUEST_OBJECT_COUNT == env->http_req_objects)
-		return duk_error(ctx, DUK_RET_EVAL_ERROR, "maximum count of HttpRequest objects was reached");
+	env = (zbx_es_env_t *)duk_to_pointer(ctx, -1);
+	duk_pop(ctx);
 
 	duk_push_this(ctx);
 
@@ -184,15 +177,14 @@ static duk_ret_t	es_httprequest_ctor(duk_context *ctx)
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_WRITEDATA, request, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_PRIVATE, request, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_SSL_VERIFYPEER, 0L, err);
+	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_TIMEOUT, (long)env->timeout, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_SSL_VERIFYHOST, 0L, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_HEADERFUNCTION, curl_header_cb, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_HEADERDATA, request, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_INTERFACE, CONFIG_SOURCE_IP, err);
 
-	duk_push_string(ctx, "\xff""\xff""d");
 	duk_push_pointer(ctx, request);
-	duk_def_prop(ctx, -3, DUK_DEFPROP_HAVE_VALUE | DUK_DEFPROP_CLEAR_WRITABLE | DUK_DEFPROP_HAVE_ENUMERABLE |
-			DUK_DEFPROP_HAVE_CONFIGURABLE);
+	duk_put_prop_string(ctx, -2, "\xff""\xff""d");
 
 	duk_push_c_function(ctx, es_httprequest_dtor, 1);
 	duk_set_finalizer(ctx, -2);
@@ -206,10 +198,7 @@ out:
 		return duk_throw(ctx);
 	}
 
-	env->http_req_objects++;
-
 	return 0;
-#undef MAX_HTTPREQUEST_OBJECT_COUNT
 }
 
 /******************************************************************************
@@ -221,12 +210,10 @@ out:
  ******************************************************************************/
 static duk_ret_t	es_httprequest_add_header(duk_context *ctx)
 {
-#define ZBX_ES_MAX_HEADERS_SIZE	ZBX_KIBIBYTE * 128
 	zbx_es_httprequest_t	*request;
 	CURLcode		err;
 	char			*utf8 = NULL;
 	int			err_index = -1;
-	size_t			header_sz;
 
 	if (NULL == (request = es_httprequest(ctx)))
 		return duk_error(ctx, DUK_RET_EVAL_ERROR, "internal scripting error: null object");
@@ -237,20 +224,9 @@ static duk_ret_t	es_httprequest_add_header(duk_context *ctx)
 		goto out;
 	}
 
-	header_sz = strlen(utf8);
-
-	if (ZBX_ES_MAX_HEADERS_SIZE < request->headers_sz + header_sz)
-	{
-		err_index = duk_push_error_object(ctx, DUK_RET_TYPE_ERROR, "headers exceeded maximum size of "
-				ZBX_FS_UI64 " bytes.", ZBX_ES_MAX_HEADERS_SIZE);
-
-		goto out;
-	}
-
 	request->headers = curl_slist_append(request->headers, utf8);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_HTTPHEADER, request->headers, err);
 	request->custom_header = 1;
-	request->headers_sz += header_sz + 1;
 out:
 	zbx_free(utf8);
 
@@ -258,7 +234,6 @@ out:
 		return duk_throw(ctx);
 
 	return 0;
-#undef ZBX_ES_MAX_HEADERS_SIZE
 }
 
 /******************************************************************************
@@ -278,7 +253,6 @@ static duk_ret_t	es_httprequest_clear_header(duk_context *ctx)
 	curl_slist_free_all(request->headers);
 	request->headers = NULL;
 	request->custom_header = 0;
-	request->headers_sz = 0;
 
 	return 0;
 }
@@ -299,20 +273,6 @@ static duk_ret_t	es_httprequest_query(duk_context *ctx, const char *http_request
 	char			*url = NULL, *contents = NULL;
 	CURLcode		err;
 	int			err_index = -1;
-	zbx_es_env_t		*env;
-	zbx_uint64_t		timeout_ms, elapsed_ms;
-
-	if (NULL == (env = zbx_es_get_env(ctx)))
-		return duk_error(ctx, DUK_RET_TYPE_ERROR, "cannot access internal environment");
-
-	elapsed_ms = zbx_get_duration_ms(&env->start_time);
-	timeout_ms = (zbx_uint64_t)env->timeout * 1000;
-
-	if (elapsed_ms >= timeout_ms)
-	{
-		err_index = duk_push_error_object(ctx, DUK_RET_EVAL_ERROR, "script execution timeout occurred");
-		goto out;
-	}
 
 	if (SUCCEED != zbx_cesu8_to_utf8(duk_to_string(ctx, 0), &url))
 	{
@@ -346,7 +306,6 @@ static duk_ret_t	es_httprequest_query(duk_context *ctx, const char *http_request
 		{
 			curl_slist_free_all(request->headers);
 			request->headers = NULL;
-			request->headers_sz = 0;
 		}
 
 		if (NULL != contents)
@@ -360,13 +319,7 @@ static duk_ret_t	es_httprequest_query(duk_context *ctx, const char *http_request
 
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_HTTPHEADER, request->headers, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_CUSTOMREQUEST, http_request, err);
-	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_TIMEOUT_MS, timeout_ms - elapsed_ms, err);
 	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_POSTFIELDS, ZBX_NULL2EMPTY_STR(contents), err);
-	ZBX_CURL_SETOPT(ctx, request->handle, ZBX_CURLOPT_ACCEPT_ENCODING, "", err);
-#if LIBCURL_VERSION_NUM >= 0x071304
-	/* CURLOPT_PROTOCOLS is supported starting with version 7.19.4 (0x071304) */
-	ZBX_CURL_SETOPT(ctx, request->handle, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS, err);
-#endif
 
 	request->data_offset = 0;
 	request->headers_in_offset = 0;
@@ -534,7 +487,7 @@ static duk_ret_t	es_httprequest_get_headers(duk_context *ctx)
 	if (0 == request->headers_in_offset)
 		return 1;
 
-	for (ptr = request->headers_in; NULL != (header = zbx_http_get_header(&ptr)); )
+	for (ptr = request->headers_in; NULL != (header = zbx_http_parse_header(&ptr)); )
 	{
 		es_put_header(ctx, idx, header);
 		zbx_free(header);
