@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -213,6 +213,12 @@ int	parse_rtc_options(const char *opt, unsigned char program_type, int *message)
 			return FAIL;
 		}
 	}
+	else if (0 != (program_type & ZBX_PROGRAM_TYPE_SERVER) && 0 == strcmp(opt, ZBX_SECRETS_RELOAD))
+	{
+		command = ZBX_RTC_SECRETS_RELOAD;
+		scope = 0;
+		data = 0;
+	}
 	else
 	{
 		zbx_error("invalid runtime control option: %s", opt);
