@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,11 +29,6 @@
 #include "sighandler.h"
 #include "sigcommon.h"
 
-#if defined(__linux__)
-#define ZBX_PID_FILE_TIMEOUT 20
-#define ZBX_PID_FILE_SLEEP_TIME 100000000
-#endif
-
 char		*CONFIG_PID_FILE = NULL;
 static int	parent_pid = -1;
 
@@ -226,7 +221,8 @@ static void	user1_signal_handler(int sig, siginfo_t *siginfo, void *context)
 						" cannot be performed for a passive proxy");
 				return;
 			}
-
+			ZBX_FALLTHROUGH;
+		case ZBX_RTC_SECRETS_RELOAD:
 			zbx_signal_process_by_type(ZBX_PROCESS_TYPE_CONFSYNCER, 1, flags);
 			break;
 		case ZBX_RTC_HOUSEKEEPER_EXECUTE:
@@ -310,6 +306,7 @@ static void	set_daemon_signal_handlers(void)
  ******************************************************************************/
 int	daemon_start(int allow_root, const char *user, unsigned int flags)
 {
+	pid_t		pid;
 	struct passwd	*pwd;
 
 	if (0 == allow_root && 0 == getuid())	/* running as root? */
@@ -366,35 +363,14 @@ int	daemon_start(int allow_root, const char *user, unsigned int flags)
 
 	if (0 == (flags & ZBX_TASK_FLAG_FOREGROUND))
 	{
-		pid_t	child_pid;
-
-		if(0 != (child_pid = zbx_fork()))
-		{
-#if defined(__linux__)
-			if (0 < child_pid)
-			{
-				int		pid_file_timeout = ZBX_PID_FILE_TIMEOUT;
-				zbx_stat_t	stat_buff;
-				struct timespec	ts = {0, ZBX_PID_FILE_SLEEP_TIME};
-
-				/* wait for the forked child to create pid file */
-				while (0 < pid_file_timeout && 0 != zbx_stat(CONFIG_PID_FILE, &stat_buff))
-				{
-					pid_file_timeout--;
-					nanosleep(&ts, NULL);
-				}
-			}
-#else
-			ZBX_UNUSED(child_pid);
-#endif
+		if (0 != (pid = zbx_fork()))
 			exit(EXIT_SUCCESS);
-		}
 
 		setsid();
 
 		signal(SIGHUP, SIG_IGN);
 
-		if (0 != zbx_fork())
+		if (0 != (pid = zbx_fork()))
 			exit(EXIT_SUCCESS);
 
 		if (-1 == chdir("/"))	/* this is to eliminate warning: ignoring return value of chdir */
