@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #include "cfg.h"
 
 extern char	*CONFIG_HOSTS_ALLOWED;
-extern char	*CONFIG_HOSTNAME;
+extern char	*CONFIG_HOSTNAMES;
 extern char	*CONFIG_HOSTNAME_ITEM;
 extern char	*CONFIG_HOST_METADATA;
 extern char	*CONFIG_HOST_METADATA_ITEM;
