@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ DB_EVENT	*zbx_add_event(unsigned char source, unsigned char object, zbx_uint64_t
 		const char *trigger_expression, const char *trigger_recovery_expression, unsigned char trigger_priority,
 		unsigned char trigger_type, const zbx_vector_ptr_t *trigger_tags,
 		unsigned char trigger_correlation_mode, const char *trigger_correlation_tag,
-		unsigned char trigger_value, const char *trigger_opdata, const char *error)
+		unsigned char trigger_value, const char *trigger_opdata, const char *event_name, const char *error)
 {
 	ZBX_UNUSED(source);
 	ZBX_UNUSED(object);
@@ -54,6 +54,7 @@ DB_EVENT	*zbx_add_event(unsigned char source, unsigned char object, zbx_uint64_t
 	ZBX_UNUSED(trigger_correlation_tag);
 	ZBX_UNUSED(trigger_value);
 	ZBX_UNUSED(trigger_opdata);
+	ZBX_UNUSED(event_name);
 	ZBX_UNUSED(error);
 
 	THIS_SHOULD_NEVER_HAPPEN;
