@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -280,8 +280,6 @@ char	*CONFIG_TLS_CIPHER_CMD		= NULL;	/* parameter '--tls-cipher' from sender com
 int	CONFIG_PASSIVE_FORKS		= 0;	/* not used in zabbix_sender, just for linking with tls.c */
 int	CONFIG_ACTIVE_FORKS		= 0;	/* not used in zabbix_sender, just for linking with tls.c */
 
-int	CONFIG_TCP_MAX_BACKLOG_SIZE	= SOMAXCONN;
-
 /* COMMAND LINE OPTIONS */
 
 /* long options */
@@ -770,10 +768,12 @@ static int	perform_data_sending(ZBX_THREAD_SENDVAL_ARGS *sendval_args, int old_s
  *                FAIL - destination has been already added                   *
  *                                                                            *
  ******************************************************************************/
-static int	sender_add_serveractive_host_cb(const char *host, unsigned short port)
+static int	sender_add_serveractive_host_cb(const char *host, unsigned short port, zbx_vector_str_t *hostnames)
 {
 	int	i;
 
+	ZBX_UNUSED(hostnames);
+
 	for (i = 0; i < destinations_count; i++)
 	{
 		if (0 == strcmp(destinations[i].host, host) && destinations[i].port == port)
@@ -828,7 +828,7 @@ static void	zbx_load_config(const char *config_file)
 			PARM_OPT,	0,			0},
 		{"ServerActive",		&cfg_active_hosts,			TYPE_STRING_LIST,
 			PARM_OPT,	0,			0},
-		{"Hostname",			&cfg_hostname,				TYPE_STRING,
+		{"Hostname",			&cfg_hostname,				TYPE_STRING_LIST,
 			PARM_OPT,	0,			0},
 		{"TLSConnect",			&cfg_tls_connect,			TYPE_STRING,
 			PARM_OPT,	0,			0},
@@ -856,25 +856,36 @@ static void	zbx_load_config(const char *config_file)
 			PARM_OPT,	0,			0},
 		{"TLSCipherPSK",		&cfg_tls_cipher_psk,			TYPE_STRING,
 			PARM_OPT,	0,			0},
-		{"ListenBacklog",		&CONFIG_TCP_MAX_BACKLOG_SIZE,		TYPE_INT,
-			PARM_OPT,	0,			INT_MAX},
 		{NULL}
 	};
 
 	/* do not complain about unknown parameters in agent configuration file */
 	parse_cfg_file(config_file, cfg, ZBX_CFG_FILE_REQUIRED, ZBX_CFG_NOT_STRICT);
 
+	/* get first hostname only */
+	if (NULL != cfg_hostname)
+	{
+		if (NULL == ZABBIX_HOSTNAME)
+		{
+			char	*p;
+
+			ZABBIX_HOSTNAME = NULL != (p = strchr(cfg_hostname, ',')) ?
+					zbx_dsprintf(NULL, "%.*s", (int)(p - cfg_hostname), cfg_hostname) :
+					zbx_strdup(NULL, cfg_hostname);
+		}
+
+		zbx_free(cfg_hostname);
+	}
+
 	zbx_fill_from_config_file(&CONFIG_SOURCE_IP, cfg_source_ip);
 
 	if (NULL == ZABBIX_SERVER)
 	{
 		if (NULL != cfg_active_hosts && '\0' != *cfg_active_hosts)
-			zbx_set_data_destination_hosts(cfg_active_hosts, sender_add_serveractive_host_cb);
+			zbx_set_data_destination_hosts(cfg_active_hosts, sender_add_serveractive_host_cb, NULL);
 	}
 	zbx_free(cfg_active_hosts);
 
-	zbx_fill_from_config_file(&ZABBIX_HOSTNAME, cfg_hostname);
-
 	zbx_fill_from_config_file(&CONFIG_TLS_CONNECT, cfg_tls_connect);
 	zbx_fill_from_config_file(&CONFIG_TLS_CA_FILE, cfg_tls_ca_file);
 	zbx_fill_from_config_file(&CONFIG_TLS_CRL_FILE, cfg_tls_crl_file);
@@ -1046,7 +1057,7 @@ static void	parse_commandline(int argc, char **argv)
 		else
 			port = (unsigned short)ZBX_DEFAULT_SERVER_PORT;
 
-		sender_add_serveractive_host_cb(ZABBIX_SERVER, port);
+		sender_add_serveractive_host_cb(ZABBIX_SERVER, port, NULL);
 	}
 
 	/* every option may be specified only once */
