@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -68,6 +68,49 @@ static	void	unblock_signals(void)
 		zabbix_log(LOG_LEVEL_WARNING,"cannot restore sigprocmask");
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_db_flush_timer_queue                                         *
+ *                                                                            *
+ * Purpose: flush timer queue to the database                                 *
+ *                                                                            *
+ ******************************************************************************/
+static void	zbx_db_flush_timer_queue(void)
+{
+	int			i;
+	zbx_vector_ptr_t	persistent_timers;
+	zbx_db_insert_t		db_insert;
+
+	zbx_vector_ptr_create(&persistent_timers);
+	zbx_dc_clear_timer_queue(&persistent_timers);
+
+	if (0 != persistent_timers.values_num)
+	{
+		zbx_db_insert_prepare(&db_insert, "trigger_queue", "objectid", "type", "clock", "ns", NULL);
+
+		for (i = 0; i < persistent_timers.values_num; i++)
+		{
+			zbx_trigger_timer_t	*timer = (zbx_trigger_timer_t *)persistent_timers.values[i];
+
+			zbx_db_insert_add_values(&db_insert, timer->objectid, timer->type, timer->eval_ts.sec,
+					timer->eval_ts.ns);
+		}
+
+		zbx_dc_free_timers(&persistent_timers);
+
+		zbx_db_insert_execute(&db_insert);
+		zbx_db_insert_clean(&db_insert);
+	}
+
+	zbx_vector_ptr_destroy(&persistent_timers);
+}
+
+static void	db_trigger_queue_cleanup(void)
+{
+	DBexecute("delete from trigger_queue");
+	zbx_db_trigger_queue_unlock();
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: main_dbsyncer_loop                                               *
@@ -108,6 +151,10 @@ ZBX_THREAD_ENTRY(dbsyncer_thread, args)
 	/* database APIs might not handle signals correctly and hang, block signals to avoid hanging */
 	block_signals();
 	DBconnect(ZBX_DB_CONNECT_NORMAL);
+
+	if (1 == process_num)
+		db_trigger_queue_cleanup();
+
 	unblock_signals();
 
 	if (SUCCEED == zbx_is_export_enabled(ZBX_FLAG_EXPTYPE_HISTORY))
@@ -122,20 +169,22 @@ ZBX_THREAD_ENTRY(dbsyncer_thread, args)
 	for (;;)
 	{
 		sec = zbx_time();
+		zbx_update_env(sec);
 
 		if (0 != sleeptime)
 			zbx_setproctitle("%s #%d [%s, syncing history]", process_name, process_num, stats);
 
 		/* clear timer trigger queue to avoid processing time triggers at exit */
 		if (!ZBX_IS_RUNNING())
-		{
-			zbx_dc_clear_timer_queue();
 			zbx_log_sync_history_cache_progress();
-		}
 
 		/* database APIs might not handle signals correctly and hang, block signals to avoid hanging */
 		block_signals();
 		zbx_sync_history_cache(&values_num, &triggers_num, &more);
+
+		if (!ZBX_IS_RUNNING() && SUCCEED != zbx_db_trigger_queue_locked())
+			zbx_db_flush_timer_queue();
+
 		unblock_signals();
 
 		total_values_num += values_num;
@@ -177,10 +226,18 @@ ZBX_THREAD_ENTRY(dbsyncer_thread, args)
 		zbx_sleep_loop(sleeptime);
 	}
 
+	/* database APIs might not handle signals correctly and hang, block signals to avoid hanging */
+	block_signals();
+	if (SUCCEED != zbx_db_trigger_queue_locked())
+		zbx_db_flush_timer_queue();
+
+	DBclose();
+	unblock_signals();
+
 	zbx_log_sync_history_cache_progress();
 
 	zbx_free(stats);
-	DBclose();
+
 	exit(EXIT_SUCCESS);
 #undef STAT_INTERVAL
 }
