@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -34,10 +34,6 @@
 extern unsigned char	process_type, program_type;
 extern int		server_num, process_num;
 
-#if defined(HAVE_POSTGRESQL)
-extern int	ZBX_TSDB_VERSION;
-#endif
-
 static int	hk_period;
 
 #define HK_INITIAL_DELETE_QUEUE_SIZE	4096
@@ -431,7 +427,7 @@ static void	hk_history_update(zbx_hk_history_rule_t *rules, int now)
 				ZBX_HK_MODE_REGULAR == *(rule = rules + value_type)->poption_mode)
 		{
 			tmp = zbx_strdup(tmp, row[2]);
-			substitute_simple_macros(NULL, NULL, NULL, NULL, &hostid, NULL, NULL, NULL, NULL, &tmp,
+			substitute_simple_macros(NULL, NULL, NULL, NULL, &hostid, NULL, NULL, NULL, NULL, NULL, &tmp,
 					MACRO_TYPE_COMMON, NULL, 0);
 
 			if (SUCCEED != is_time_suffix(tmp, &history, ZBX_LENGTH_UNLIMITED))
@@ -462,7 +458,7 @@ static void	hk_history_update(zbx_hk_history_rule_t *rules, int now)
 				continue;
 
 			tmp = zbx_strdup(tmp, row[3]);
-			substitute_simple_macros(NULL, NULL, NULL, NULL, &hostid, NULL, NULL, NULL, NULL, &tmp,
+			substitute_simple_macros(NULL, NULL, NULL, NULL, &hostid, NULL, NULL, NULL, NULL, NULL, &tmp,
 					MACRO_TYPE_COMMON, NULL, 0);
 
 			if (SUCCEED != is_time_suffix(tmp, &trends, ZBX_LENGTH_UNLIMITED))
@@ -610,43 +606,6 @@ static void	hk_drop_partition_for_rule(zbx_hk_history_rule_t *rule, int now)
 #endif
 }
 
-#if defined(HAVE_POSTGRESQL)
-static int hk_history_has_compressed_chunks(void)
-{
-	const char	*table_list;
-
-	table_list = (1 == ZBX_DB_TSDB_V1 ? ZBX_TSDB1_HISTORY_TABLES : ZBX_TSDB2_HISTORY_TABLES);
-
-	return zbx_tsdb_table_has_compressed_chunks(table_list);
-}
-
-static int hk_trends_has_compressed_chunks(void)
-{
-	const char	*table_list;
-
-	table_list = (1 == ZBX_DB_TSDB_V1 ? ZBX_TSDB1_TRENDS_TABLES : ZBX_TSDB2_TRENDS_TABLES);
-
-	return zbx_tsdb_table_has_compressed_chunks(table_list);
-}
-
-static void	hk_tsdb_check_config()
-{
-	if (cfg.hk.history_global == ZBX_HK_OPTION_DISABLED && cfg.hk.history_mode == ZBX_HK_OPTION_ENABLED &&
-		SUCCEED == hk_history_has_compressed_chunks())
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "Incorrect configuration. Override item history period is disabled, but "
-				"historical data is compressed. Housekeeper may skip deleting this data.");
-	}
-
-	if (cfg.hk.trends_global == ZBX_HK_OPTION_DISABLED && cfg.hk.trends_mode == ZBX_HK_OPTION_ENABLED &&
-			SUCCEED == hk_trends_has_compressed_chunks())
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "Incorrect configuration. Override item trends period is disabled, but "
-				"trends data is compressed. Housekeeper may skip deleting this data.");
-	}
-}
-#endif
-
 /******************************************************************************
  *                                                                            *
  * Function: housekeeping_history_and_trends                                  *
@@ -662,16 +621,12 @@ static int	housekeeping_history_and_trends(int now)
 {
 	int			deleted = 0, i, rc;
 	zbx_hk_history_rule_t	*rule;
-#if defined(HAVE_POSTGRESQL)
-	int			ignore_history = 0, ignore_trends = 0;
-#endif
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() now:%d", __func__, now);
 
 	/* prepare delete queues for all history housekeeping rules */
 	hk_history_delete_queue_prepare_all(hk_history_rules, now);
 
-
 	/* Loop through the history rules. Each rule is a history table (such as history_log, trends_uint, etc) */
 	/* we need to clear records from */
 	for (rule = hk_history_rules; NULL != rule->table; rule++)
@@ -689,47 +644,6 @@ static int	housekeeping_history_and_trends(int now)
 			continue;
 		}
 
-#if defined(HAVE_POSTGRESQL)
-		if (ZBX_TSDB_VERSION > 0)
-		{
-			if (0 == strcmp(rule->history, "history"))
-			{
-				if (1 == ignore_history)
-				{
-					hk_history_release(rule);
-					continue;
-				}
-
-				if (SUCCEED == hk_history_has_compressed_chunks())
-				{
-					zabbix_log(LOG_LEVEL_WARNING, "Unable to perform housekeeping for history "
-							"tables due to having compressed chunks and disabled item history period override.");
-
-					ignore_history = 1;
-					hk_history_release(rule);
-					continue;
-				}
-			}
-			else if (0 == strcmp(rule->history, "trends"))
-			{
-				if (1 == ignore_trends)
-				{
-					hk_history_release(rule);
-					continue;
-				}
-
-				if (SUCCEED == hk_trends_has_compressed_chunks())
-				{
-					zabbix_log(LOG_LEVEL_WARNING, "Unable to perform housekeeping for trends "
-							"tables due to having compressed chunks and disabled item trends period override.");
-
-					ignore_trends = 1;
-					hk_history_release(rule);
-					continue;
-				}
-			}
-		}
-#endif
 		/* process delete queue for the housekeeping rule */
 
 		zbx_vector_ptr_sort(&rule->delete_queue, hk_item_update_cache_compare);
@@ -797,7 +711,7 @@ static int	housekeeping_process_rule(int now, zbx_hk_rule_t *rule)
 	{
 		char			buffer[MAX_STRING_LEN];
 		char			*sql = NULL;
-		size_t			sql_alloc = 0, sql_offset;
+		size_t			sql_alloc = 0, sql_offset = 0;
 		zbx_vector_uint64_t	ids;
 		int			ret;
 
@@ -1241,16 +1155,6 @@ ZBX_THREAD_ENTRY(housekeeper_thread, args)
 
 	zbx_set_sigusr_handler(zbx_housekeeper_sigusr_handler);
 
-#if defined(HAVE_POSTGRESQL)
-	if (ZBX_TSDB_VERSION > 0)
-	{
-		zbx_config_get(&cfg, ZBX_CONFIG_FLAGS_HOUSEKEEPER);
-		DBconnect(ZBX_DB_CONNECT_NORMAL);
-		hk_tsdb_check_config();
-		DBclose();
-	}
-#endif
-
 	while (ZBX_IS_RUNNING())
 	{
 		sec = zbx_time();
