@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -790,7 +790,7 @@ static int	ipmi_manager_schedule_requests(zbx_ipmi_manager_t *manager, int now,
 			zbx_timespec(&ts);
 			zbx_preprocess_item_value(items[i].itemid, items[i].host.hostid, items[i].value_type,
 					items[i].flags, NULL, &ts, state, error);
-			DCrequeue_items(&items[i].itemid, &state, &ts.sec, &errcode, 1);
+			DCrequeue_items(&items[i].itemid, &ts.sec, &errcode, 1);
 			zbx_free(error);
 			continue;
 		}
@@ -958,13 +958,13 @@ static void	ipmi_manager_process_value_result(zbx_ipmi_manager_t *manager, zbx_i
 			break;
 		default:
 			/* don't change item's state when network related error occurs */
-			break;
+			state = poller->request->item_state;
 	}
 
 	zbx_free(value);
 
 	/* put back the item in configuration cache IPMI poller queue */
-	DCrequeue_items(&itemid, &state, &ts.sec, &errcode, 1);
+	DCrequeue_items(&itemid, &ts.sec, &errcode, 1);
 
 	ipmi_poller_free_request(poller);
 	ipmi_manager_process_poller_queue(manager, poller, now);
