@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,15 +27,6 @@
 #include "zbxregexp.h"
 #include "proxy.h"
 
-typedef enum
-{
-	OPERATION_OBJECT_ITEM_PROTOTYPE = 0,
-	OPERATION_OBJECT_TRIGGER_PROTOTYPE,
-	OPERATION_OBJECT_GRAPH_PROTOTYPE,
-	OPERATION_OBJECT_HOST_PROTOTYPE
-}
-zbx_operation_object_t;
-
 #define OVERRIDE_STOP_TRUE	1
 
 /* lld rule filter condition (item_condition table record) */
@@ -69,24 +60,6 @@ typedef struct
 }
 lld_override_t;
 
-typedef struct
-{
-	zbx_uint64_t		override_operationid;
-	char			*value;
-	char			*delay;
-	char			*history;
-	char			*trends;
-	zbx_vector_ptr_pair_t	trigger_tags;
-	zbx_vector_uint64_t	templateids;
-	unsigned char		operationtype;
-	unsigned char		operator;
-	unsigned char		status;
-	unsigned char		discover;
-	unsigned char		severity;
-	signed char		inventory_mode;
-}
-lld_override_operation_t;
-
 /******************************************************************************
  *                                                                            *
  * Function: lld_condition_free                                               *
@@ -198,7 +171,7 @@ static int	lld_filter_condition_add(zbx_vector_ptr_t *conditions, const char *id
 	}
 	else
 	{
-		substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, NULL, item, NULL, NULL,
+		substitute_simple_macros(NULL, NULL, NULL, NULL, NULL, NULL, item, NULL, NULL, NULL,
 				&condition->regexp, MACRO_TYPE_LLD_FILTER, NULL, 0);
 	}
 
@@ -300,14 +273,13 @@ static int	filter_condition_match(const struct zbx_json_parse *jp_row, const zbx
 static int	filter_evaluate_and_or(const lld_filter_t *filter, const struct zbx_json_parse *jp_row,
 		const zbx_vector_ptr_t *lld_macro_paths)
 {
-	int	i, ret = SUCCEED;
+	int	i, ret = SUCCEED, rc = SUCCEED;
 	char	*lastmacro = NULL;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
 	for (i = 0; i < filter->conditions.values_num; i++)
 	{
-		int			rc;
 		const lld_condition_t	*condition = (lld_condition_t *)filter->conditions.values[i];
 
 		rc = filter_condition_match(jp_row, lld_macro_paths, condition);
@@ -605,122 +577,32 @@ static int	lld_override_conditions_load(zbx_vector_ptr_t *overrides, const zbx_v
 static void	lld_override_operations_load(zbx_vector_ptr_t *overrides, const zbx_vector_uint64_t *overrideids,
 		char **sql, size_t *sql_alloc)
 {
-	size_t				sql_offset = 0;
-	DB_RESULT			result;
-	DB_ROW				row;
-	lld_override_t			*override = NULL;
-	lld_override_operation_t	*override_operation = NULL;
+	lld_override_t			*override;
+	zbx_lld_override_operation_t	*op;
+	zbx_vector_ptr_t		ops;
+	int				i, index;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
-	zbx_strcpy_alloc(sql, sql_alloc, &sql_offset,
-			"select o.lld_overrideid,o.lld_override_operationid,o.operationobject,o.operator,o.value,"
-				"s.status,"
-				"d.discover,"
-				"p.delay,"
-				"h.history,"
-				"t.trends,"
-				"os.severity,"
-				"ot.tag,ot.value,"
-				"ote.templateid,"
-				"i.inventory_mode"
-			" from lld_override_operation o"
-			" left join lld_override_opstatus s"
-				" on o.lld_override_operationid=s.lld_override_operationid"
-			" left join lld_override_opdiscover d"
-				" on o.lld_override_operationid=d.lld_override_operationid"
-			" left join lld_override_opperiod p"
-				" on o.lld_override_operationid=p.lld_override_operationid"
-			" left join lld_override_ophistory h"
-				" on o.lld_override_operationid=h.lld_override_operationid"
-			" left join lld_override_optrends t"
-				" on o.lld_override_operationid=t.lld_override_operationid"
-			" left join lld_override_opseverity os"
-				" on o.lld_override_operationid=os.lld_override_operationid"
-			" left join lld_override_optag ot"
-				" on o.lld_override_operationid=ot.lld_override_operationid"
-			" left join lld_override_optemplate ote"
-				" on o.lld_override_operationid=ote.lld_override_operationid"
-			" left join lld_override_opinventory i"
-				" on o.lld_override_operationid=i.lld_override_operationid"
-			" where");
-	DBadd_condition_alloc(sql, sql_alloc, &sql_offset, "o.lld_overrideid", overrideids->values,
-			overrideids->values_num);
-	zbx_strcpy_alloc(sql, sql_alloc, &sql_offset, " order by o.lld_override_operationid");
+	zbx_vector_ptr_create(&ops);
 
-	result = DBselect("%s", *sql);
-	while (NULL != (row = DBfetch(result)))
+	zbx_load_lld_override_operations(overrideids, sql, sql_alloc, &ops);
+
+	for (i = 0; i < ops.values_num; i++)
 	{
-		zbx_uint64_t	overrideid, override_operationid;
-
-		ZBX_STR2UINT64(overrideid, row[0]);
-		if (NULL == override || override->overrideid != overrideid)
+		op = (zbx_lld_override_operation_t *)ops.values[i];
+		if (FAIL == (index = zbx_vector_ptr_bsearch(overrides, &op->overrideid,
+				ZBX_DEFAULT_UINT64_PTR_COMPARE_FUNC)))
 		{
-			int	index;
-
-			if (FAIL == (index = zbx_vector_ptr_bsearch(overrides, &overrideid,
-					ZBX_DEFAULT_UINT64_PTR_COMPARE_FUNC)))
-			{
-				THIS_SHOULD_NEVER_HAPPEN;
-				continue;
-			}
-			override = (lld_override_t *)overrides->values[index];
+			zbx_lld_override_operation_free(op);
+			THIS_SHOULD_NEVER_HAPPEN;
+			continue;
 		}
-
-		ZBX_STR2UINT64(override_operationid, row[1]);
-		if (NULL == override_operation || override_operation->override_operationid != override_operationid)
-		{
-			override_operation = (lld_override_operation_t *)zbx_malloc(NULL,
-					sizeof(lld_override_operation_t));
-
-			zbx_vector_ptr_pair_create(&override_operation->trigger_tags);
-			zbx_vector_uint64_create(&override_operation->templateids);
-
-			override_operation->override_operationid = override_operationid;
-			override_operation->operationtype = (unsigned char)atoi(row[2]);
-			override_operation->operator = (unsigned char)atoi(row[3]);
-			override_operation->value = zbx_strdup(NULL, row[4]);
-
-			override_operation->status = FAIL == DBis_null(row[5]) ? (unsigned char)atoi(row[5]) :
-					ZBX_PROTOTYPE_STATUS_COUNT;
-
-			override_operation->discover = FAIL == DBis_null(row[6]) ? (unsigned char)atoi(row[6]) :
-					ZBX_PROTOTYPE_DISCOVER_COUNT;
-
-			zbx_vector_ptr_append(&override->override_operations, override_operation);
-		}
-
-		override_operation->delay = FAIL == DBis_null(row[7]) ? zbx_strdup(NULL, row[7]) :
-				NULL;
-		override_operation->history = FAIL == DBis_null(row[8]) ? zbx_strdup(NULL, row[8]) :
-				NULL;
-		override_operation->trends = FAIL == DBis_null(row[9]) ? zbx_strdup(NULL, row[9]) :
-				NULL;
-		override_operation->severity = FAIL == DBis_null(row[10]) ? (unsigned char)atoi(row[10]) :
-				TRIGGER_SEVERITY_COUNT;
-
-		if (FAIL == DBis_null(row[11]))
-		{
-			zbx_ptr_pair_t	pair;
-
-			pair.first = zbx_strdup(NULL, row[11]);
-			pair.second = zbx_strdup(NULL, row[12]);
-
-			zbx_vector_ptr_pair_append(&override_operation->trigger_tags, pair);
-		}
-
-		if (FAIL == DBis_null(row[13]))
-		{
-			zbx_uint64_t	templateid;
-
-			ZBX_STR2UINT64(templateid, row[13]);
-			zbx_vector_uint64_append(&override_operation->templateids, templateid);
-		}
-
-		override_operation->inventory_mode = FAIL == DBis_null(row[14]) ? (signed char)atoi(row[14]) :
-				HOST_INVENTORY_COUNT;
+		override = (lld_override_t *)overrides->values[index];
+		zbx_vector_ptr_append(&override->override_operations, op);
 	}
-	DBfree_result(result);
+
+	zbx_vector_ptr_destroy(&ops);
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
@@ -732,27 +614,6 @@ static int	lld_overrides_compare_by_step(const void *override1, const void *over
 	return 0;
 }
 
-static void	lld_override_operation_free(lld_override_operation_t *override_operation)
-{
-	int	i;
-
-	for (i = 0; i < override_operation->trigger_tags.values_num; i++)
-	{
-		zbx_free(override_operation->trigger_tags.values[i].first);
-		zbx_free(override_operation->trigger_tags.values[i].second);
-	}
-	zbx_vector_ptr_pair_destroy(&override_operation->trigger_tags);
-
-	zbx_vector_uint64_destroy(&override_operation->templateids);
-
-	zbx_free(override_operation->value);
-
-	zbx_free(override_operation->delay);
-	zbx_free(override_operation->history);
-	zbx_free(override_operation->trends);
-	zbx_free(override_operation);
-}
-
 static void	lld_dump_overrides(const zbx_vector_ptr_t *overrides)
 {
 	int			i;
@@ -770,10 +631,10 @@ static void	lld_dump_overrides(const zbx_vector_ptr_t *overrides)
 
 		for (j = 0; j < override->override_operations.values_num; j++)
 		{
-			lld_override_operation_t	*override_operation;
+			zbx_lld_override_operation_t	*override_operation;
 			int				k;
 
-			override_operation = (lld_override_operation_t *)override->override_operations.values[j];
+			override_operation = (zbx_lld_override_operation_t *)override->override_operations.values[j];
 
 			zabbix_log(LOG_LEVEL_TRACE, "    override_operationid:" ZBX_FS_UI64,
 					override_operation->override_operationid);
@@ -786,11 +647,11 @@ static void	lld_dump_overrides(const zbx_vector_ptr_t *overrides)
 			zabbix_log(LOG_LEVEL_TRACE, "    history '%s'", ZBX_NULL2STR(override_operation->history));
 			zabbix_log(LOG_LEVEL_TRACE, "    trends '%s'", ZBX_NULL2STR(override_operation->trends));
 			zabbix_log(LOG_LEVEL_TRACE, "    inventory_mode: %d", override_operation->inventory_mode);
-			for (k = 0; k < override_operation->trigger_tags.values_num; k++)
+			for (k = 0; k < override_operation->tags.values_num; k++)
 			{
 				zabbix_log(LOG_LEVEL_TRACE, "    tag:'%s' value:'%s'",
-						(char *)override_operation->trigger_tags.values[k].first,
-						(char *)override_operation->trigger_tags.values[k].second);
+						override_operation->tags.values[k]->tag,
+						override_operation->tags.values[k]->value);
 			}
 
 			for (k = 0; k < override_operation->templateids.values_num; k++)
@@ -869,7 +730,7 @@ static void	lld_override_free(lld_override_t *override)
 {
 	lld_filter_clean(&override->filter);
 
-	zbx_vector_ptr_clear_ext(&override->override_operations, (zbx_clean_func_t)lld_override_operation_free);
+	zbx_vector_ptr_clear_ext(&override->override_operations, (zbx_clean_func_t)zbx_lld_override_operation_free);
 	zbx_vector_ptr_destroy(&override->override_operations);
 	zbx_free(override);
 }
@@ -908,11 +769,11 @@ void	lld_override_item(const zbx_vector_ptr_t *overrides, const char *name, cons
 
 		for (j = 0; j < override->override_operations.values_num; j++)
 		{
-			const lld_override_operation_t	*override_operation;
+			const zbx_lld_override_operation_t	*override_operation;
 
-			override_operation = (const lld_override_operation_t *)override->override_operations.values[j];
+			override_operation = (const zbx_lld_override_operation_t *)override->override_operations.values[j];
 
-			if (OPERATION_OBJECT_ITEM_PROTOTYPE != override_operation->operationtype)
+			if (ZBX_LLD_OVERRIDE_OP_OBJECT_ITEM != override_operation->operationtype)
 				continue;
 
 			zabbix_log(LOG_LEVEL_TRACE, "%s() operationid:" ZBX_FS_UI64 " cond.value:'%s' name: '%s'",
@@ -963,7 +824,7 @@ void	lld_override_item(const zbx_vector_ptr_t *overrides, const char *name, cons
 }
 
 void	lld_override_trigger(const zbx_vector_ptr_t *overrides, const char *name, unsigned char *severity,
-		zbx_vector_ptr_pair_t *override_tags, unsigned char *status, unsigned char *discover)
+		zbx_vector_db_tag_ptr_t *override_tags, unsigned char *status, unsigned char *discover)
 {
 	int	i, j, k;
 
@@ -977,11 +838,11 @@ void	lld_override_trigger(const zbx_vector_ptr_t *overrides, const char *name, u
 
 		for (j = 0; j < override->override_operations.values_num; j++)
 		{
-			const lld_override_operation_t	*override_operation;
+			const zbx_lld_override_operation_t	*override_operation;
 
-			override_operation = (const lld_override_operation_t *)override->override_operations.values[j];
+			override_operation = (const zbx_lld_override_operation_t *)override->override_operations.values[j];
 
-			if (OPERATION_OBJECT_TRIGGER_PROTOTYPE != override_operation->operationtype)
+			if (ZBX_LLD_OVERRIDE_OP_OBJECT_TRIGGER != override_operation->operationtype)
 				continue;
 
 			zabbix_log(LOG_LEVEL_TRACE, "%s() operationid:" ZBX_FS_UI64 " cond.value:'%s' name: '%s'",
@@ -1000,8 +861,8 @@ void	lld_override_trigger(const zbx_vector_ptr_t *overrides, const char *name, u
 			if (TRIGGER_SEVERITY_COUNT != override_operation->severity)
 				*severity = override_operation->severity;
 
-			for (k = 0; k < override_operation->trigger_tags.values_num; k++)
-				zbx_vector_ptr_pair_append(override_tags, override_operation->trigger_tags.values[k]);
+			for (k = 0; k < override_operation->tags.values_num; k++)
+				zbx_vector_db_tag_ptr_append(override_tags, override_operation->tags.values[k]);
 
 			if (NULL != status)
 			{
@@ -1029,7 +890,8 @@ void	lld_override_trigger(const zbx_vector_ptr_t *overrides, const char *name, u
 }
 
 void	lld_override_host(const zbx_vector_ptr_t *overrides, const char *name, zbx_vector_uint64_t *lnk_templateids,
-		signed char *inventory_mode, unsigned char *status, unsigned char *discover)
+		char *inventory_mode, zbx_vector_db_tag_ptr_t *override_tags, unsigned char *status,
+		unsigned char *discover)
 {
 	int	i, j, k;
 
@@ -1043,11 +905,11 @@ void	lld_override_host(const zbx_vector_ptr_t *overrides, const char *name, zbx_
 
 		for (j = 0; j < override->override_operations.values_num; j++)
 		{
-			const lld_override_operation_t	*override_operation;
+			const zbx_lld_override_operation_t	*override_operation;
 
-			override_operation = (const lld_override_operation_t *)override->override_operations.values[j];
+			override_operation = (const zbx_lld_override_operation_t *)override->override_operations.values[j];
 
-			if (OPERATION_OBJECT_HOST_PROTOTYPE != override_operation->operationtype)
+			if (ZBX_LLD_OVERRIDE_OP_OBJECT_HOST != override_operation->operationtype)
 				continue;
 
 			zabbix_log(LOG_LEVEL_TRACE, "%s() operationid:" ZBX_FS_UI64 " cond.value:'%s' name: '%s'",
@@ -1069,6 +931,9 @@ void	lld_override_host(const zbx_vector_ptr_t *overrides, const char *name, zbx_
 			if (HOST_INVENTORY_COUNT != override_operation->inventory_mode)
 				*inventory_mode = override_operation->inventory_mode;
 
+			for (k = 0; k < override_operation->tags.values_num; k++)
+				zbx_vector_db_tag_ptr_append(override_tags, override_operation->tags.values[k]);
+
 			if (NULL != status)
 			{
 				switch (override_operation->status)
@@ -1108,11 +973,11 @@ void	lld_override_graph(const zbx_vector_ptr_t *overrides, const char *name,	uns
 
 		for (j = 0; j < override->override_operations.values_num; j++)
 		{
-			const lld_override_operation_t	*override_operation;
+			const zbx_lld_override_operation_t	*override_operation;
 
-			override_operation = (const lld_override_operation_t *)override->override_operations.values[j];
+			override_operation = (const zbx_lld_override_operation_t *)override->override_operations.values[j];
 
-			if (OPERATION_OBJECT_GRAPH_PROTOTYPE != override_operation->operationtype)
+			if (ZBX_LLD_OVERRIDE_OP_OBJECT_GRAPH != override_operation->operationtype)
 				continue;
 
 			zabbix_log(LOG_LEVEL_TRACE, "%s() operationid:" ZBX_FS_UI64 " cond.value:'%s' name: '%s'",
@@ -1136,8 +1001,7 @@ void	lld_override_graph(const zbx_vector_ptr_t *overrides, const char *name,	uns
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
-int	lld_validate_item_override_no_discover(const zbx_vector_ptr_t *overrides, const char *name,
-		unsigned char override_default)
+int	lld_validate_item_override_no_discover(const zbx_vector_ptr_t *overrides, const char *name)
 {
 	int	i, j;
 
@@ -1149,20 +1013,21 @@ int	lld_validate_item_override_no_discover(const zbx_vector_ptr_t *overrides, co
 
 		for (j = 0; j < override->override_operations.values_num; j++)
 		{
-			const lld_override_operation_t	*override_operation;
+			const zbx_lld_override_operation_t	*override_operation;
 
-			override_operation = (const lld_override_operation_t *)override->override_operations.values[j];
+			override_operation = (const zbx_lld_override_operation_t *)override->override_operations.values[j];
 
-			if (OPERATION_OBJECT_ITEM_PROTOTYPE == override_operation->operationtype &&
+			if (ZBX_LLD_OVERRIDE_OP_OBJECT_ITEM == override_operation->operationtype &&
+					ZBX_PROTOTYPE_NO_DISCOVER == override_operation->discover &&
 					SUCCEED == regexp_strmatch_condition(name, override_operation->value,
 					override_operation->operator))
 			{
-				return ZBX_PROTOTYPE_NO_DISCOVER == override_operation->discover ? FAIL : SUCCEED;
+				return FAIL;
 			}
 		}
 	}
 
-	return ZBX_PROTOTYPE_NO_DISCOVER == override_default ? FAIL : SUCCEED;
+	return SUCCEED;
 }
 
 static int	lld_rows_get(const char *value, lld_filter_t *filter, zbx_vector_ptr_t *lld_rows,
@@ -1325,7 +1190,7 @@ int	lld_process_discovery_rule(zbx_uint64_t lld_ruleid, const char *value, char
 		filter.evaltype = atoi(row[2]);
 		filter.expression = zbx_strdup(NULL, row[3]);
 		lifetime_str = zbx_strdup(NULL, row[4]);
-		substitute_simple_macros(NULL, NULL, NULL, NULL, &hostid, NULL, NULL, NULL, NULL,
+		substitute_simple_macros(NULL, NULL, NULL, NULL, &hostid, NULL, NULL, NULL, NULL, NULL,
 				&lifetime_str, MACRO_TYPE_COMMON, NULL, 0);
 
 		if (SUCCEED != is_time_suffix(lifetime_str, &lifetime, ZBX_LENGTH_UNLIMITED))
