@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -181,6 +181,21 @@ static int	item_preproc_multiplier_variant(unsigned char value_type, zbx_variant
 	return SUCCEED;
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: item_preproc_validate_notsupport                                 *
+ *                                                                            *
+ * Purpose: executes during notsupported item preprocessing                   *
+ *                                                                            *
+ * Return value: FAIL - for further error handling                            *
+ *                                                                            *
+ ******************************************************************************/
+static int	item_preproc_validate_notsupport(char **errmsg)
+{
+	*errmsg = zbx_dsprintf(*errmsg, "item is not supported");
+	return FAIL;
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: item_preproc_multiplier                                          *
@@ -319,6 +334,7 @@ static int	item_preproc_delta_uint64(zbx_variant_t *value, const zbx_timespec_t
 static int	item_preproc_delta(unsigned char value_type, zbx_variant_t *value, const zbx_timespec_t *ts,
 		unsigned char op_type, zbx_variant_t *history_value, zbx_timespec_t *history_ts, char **errmsg)
 {
+	int				ret = FAIL;
 	zbx_variant_t			value_num;
 
 	if (FAIL == zbx_item_preproc_convert_value_to_numeric(&value_num, value, value_type, errmsg))
@@ -328,8 +344,6 @@ static int	item_preproc_delta(unsigned char value_type, zbx_variant_t *value, co
 
 	if (ZBX_VARIANT_NONE != history_value->type)
 	{
-		int				ret;
-
 		zbx_variant_copy(value, &value_num);
 
 		if (ZBX_VARIANT_DBL == value->type || ZBX_VARIANT_DBL == history_value->type)
@@ -2184,6 +2198,9 @@ int	zbx_item_preproc(unsigned char value_type, zbx_variant_t *value, const zbx_t
 		case ZBX_PREPROC_STR_REPLACE:
 			ret = item_preproc_str_replace(value, op->params, error);
 			break;
+		case ZBX_PREPROC_VALIDATE_NOT_SUPPORTED:
+			ret = item_preproc_validate_notsupport(error);
+			break;
 		default:
 			*error = zbx_dsprintf(*error, "unknown preprocessing operation");
 			ret = FAIL;
