@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 #include "log.h"
 #include "zbxserver.h"
 #include "zbxregexp.h"
-#include "zbxcompress.h"
 
 #include "active.h"
 #include "../../libs/zbxcrypto/tls_tcp_active.h"
@@ -389,16 +388,12 @@ int	send_list_of_active_checks(zbx_socket_t *sock, char *request)
 	if (0 != itemids.values_num)
 	{
 		DC_ITEM		*dc_items;
-		int		*errcodes, now;
-		zbx_config_t	cfg;
+		int		*errcodes;
 
 		dc_items = (DC_ITEM *)zbx_malloc(NULL, sizeof(DC_ITEM) * itemids.values_num);
 		errcodes = (int *)zbx_malloc(NULL, sizeof(int) * itemids.values_num);
 
 		DCconfig_get_items_by_itemids(dc_items, itemids.values, errcodes, itemids.values_num);
-		zbx_config_get(&cfg, ZBX_CONFIG_FLAGS_REFRESH_UNSUPPORTED);
-
-		now = time(NULL);
 
 		for (i = 0; i < itemids.values_num; i++)
 		{
@@ -417,15 +412,6 @@ int	send_list_of_active_checks(zbx_socket_t *sock, char *request)
 			if (HOST_STATUS_MONITORED != dc_items[i].host.status)
 				continue;
 
-			if (ITEM_STATE_NOTSUPPORTED == dc_items[i].state)
-			{
-				if (0 == cfg.refresh_unsupported)
-					continue;
-
-				if (dc_items[i].lastclock + cfg.refresh_unsupported > now)
-					continue;
-			}
-
 			if (SUCCEED != zbx_interval_preproc(dc_items[i].delay, &delay, NULL, NULL))
 				continue;
 
@@ -433,8 +419,6 @@ int	send_list_of_active_checks(zbx_socket_t *sock, char *request)
 					dc_items[i].key_orig, delay, dc_items[i].lastlogsize);
 		}
 
-		zbx_config_clean(&cfg);
-
 		DCconfig_clean_items(dc_items, errcodes, itemids.values_num);
 
 		zbx_free(errcodes);
@@ -552,17 +536,15 @@ out:
 int	send_list_of_active_checks_json(zbx_socket_t *sock, struct zbx_json_parse *jp)
 {
 	char			host[HOST_HOST_LEN_MAX], tmp[MAX_STRING_LEN], ip[INTERFACE_IP_LEN_MAX],
-				error[MAX_STRING_LEN], *host_metadata = NULL, *interface = NULL, *buffer = NULL;
+				error[MAX_STRING_LEN], *host_metadata = NULL, *interface = NULL;
 	struct zbx_json		json;
 	int			ret = FAIL, i, version;
 	zbx_uint64_t		hostid;
 	size_t			host_metadata_alloc = 1;	/* for at least NUL-termination char */
 	size_t			interface_alloc = 1;		/* for at least NUL-termination char */
-	size_t			buffer_size, reserved = 0;
 	unsigned short		port;
 	zbx_vector_uint64_t	itemids;
 	zbx_conn_flags_t	flag = ZBX_CONN_DEFAULT;
-	zbx_config_t		cfg;
 
 	zbx_vector_ptr_t	regexps;
 	zbx_vector_str_t	names;
@@ -635,7 +617,6 @@ int	send_list_of_active_checks_json(zbx_socket_t *sock, struct zbx_json_parse *j
 	}
 
 	zbx_vector_uint64_create(&itemids);
-	zbx_config_get(&cfg, ZBX_CONFIG_FLAGS_REFRESH_UNSUPPORTED);
 
 	get_list_of_active_checks(hostid, &itemids);
 
@@ -646,15 +627,13 @@ int	send_list_of_active_checks_json(zbx_socket_t *sock, struct zbx_json_parse *j
 	if (0 != itemids.values_num)
 	{
 		DC_ITEM		*dc_items;
-		int		*errcodes, now, delay;
+		int		*errcodes, delay;
 
 		dc_items = (DC_ITEM *)zbx_malloc(NULL, sizeof(DC_ITEM) * itemids.values_num);
 		errcodes = (int *)zbx_malloc(NULL, sizeof(int) * itemids.values_num);
 
 		DCconfig_get_items_by_itemids(dc_items, itemids.values, errcodes, itemids.values_num);
 
-		now = time(NULL);
-
 		for (i = 0; i < itemids.values_num; i++)
 		{
 			if (SUCCEED != errcodes[i])
@@ -670,15 +649,6 @@ int	send_list_of_active_checks_json(zbx_socket_t *sock, struct zbx_json_parse *j
 			if (HOST_STATUS_MONITORED != dc_items[i].host.status)
 				continue;
 
-			if (ZBX_COMPONENT_VERSION(4,4) > version && ITEM_STATE_NOTSUPPORTED == dc_items[i].state)
-			{
-				if (0 == cfg.refresh_unsupported)
-					continue;
-
-				if (dc_items[i].lastclock + cfg.refresh_unsupported > now)
-					continue;
-			}
-
 			if (SUCCEED != zbx_interval_preproc(dc_items[i].delay, &delay, NULL, NULL))
 				continue;
 
@@ -725,17 +695,16 @@ int	send_list_of_active_checks_json(zbx_socket_t *sock, struct zbx_json_parse *j
 
 	zbx_json_close(&json);
 
-	if (ZBX_COMPONENT_VERSION(4,4) <= version)
-		zbx_json_adduint64(&json, ZBX_PROTO_TAG_REFRESH_UNSUPPORTED, cfg.refresh_unsupported);
+	if (ZBX_COMPONENT_VERSION(4,4) == version || ZBX_COMPONENT_VERSION(5,0) == version)
+		zbx_json_adduint64(&json, ZBX_PROTO_TAG_REFRESH_UNSUPPORTED, 600);
 
-	zbx_config_clean(&cfg);
 	zbx_vector_uint64_destroy(&itemids);
 
 	DCget_expressions_by_names(&regexps, (const char * const *)names.values, names.values_num);
 
 	if (0 < regexps.values_num)
 	{
-		char	str[32];
+		char	buffer[32];
 
 		zbx_json_addarray(&json, ZBX_PROTO_TAG_REGEXP);
 
@@ -747,14 +716,14 @@ int	send_list_of_active_checks_json(zbx_socket_t *sock, struct zbx_json_parse *j
 			zbx_json_addstring(&json, "name", regexp->name, ZBX_JSON_TYPE_STRING);
 			zbx_json_addstring(&json, "expression", regexp->expression, ZBX_JSON_TYPE_STRING);
 
-			zbx_snprintf(str, sizeof(str), "%d", regexp->expression_type);
-			zbx_json_addstring(&json, "expression_type", str, ZBX_JSON_TYPE_INT);
+			zbx_snprintf(buffer, sizeof(buffer), "%d", regexp->expression_type);
+			zbx_json_addstring(&json, "expression_type", buffer, ZBX_JSON_TYPE_INT);
 
-			zbx_snprintf(str, sizeof(str), "%c", regexp->exp_delimiter);
-			zbx_json_addstring(&json, "exp_delimiter", str, ZBX_JSON_TYPE_STRING);
+			zbx_snprintf(buffer, sizeof(buffer), "%c", regexp->exp_delimiter);
+			zbx_json_addstring(&json, "exp_delimiter", buffer, ZBX_JSON_TYPE_STRING);
 
-			zbx_snprintf(str, sizeof(str), "%d", regexp->case_sensitive);
-			zbx_json_addstring(&json, "case_sensitive", str, ZBX_JSON_TYPE_INT);
+			zbx_snprintf(buffer, sizeof(buffer), "%d", regexp->case_sensitive);
+			zbx_json_addstring(&json, "case_sensitive", buffer, ZBX_JSON_TYPE_INT);
 
 			zbx_json_close(&json);
 		}
@@ -764,31 +733,10 @@ int	send_list_of_active_checks_json(zbx_socket_t *sock, struct zbx_json_parse *j
 
 	zabbix_log(LOG_LEVEL_DEBUG, "%s() sending [%s]", __func__, json.buffer);
 
-	if (0 != (ZBX_TCP_COMPRESS & sock->protocol))
-	{
-		if (SUCCEED != zbx_compress(json.buffer, json.buffer_size, &buffer, &buffer_size))
-		{
-			zbx_snprintf(error, MAX_STRING_LEN, "cannot compress data: %s", zbx_compress_strerror());
-			goto error;
-		}
-
-		reserved = json.buffer_size;
-		zbx_json_free(&json);	/* json buffer can be large, free as fast as possible */
-
-		if (SUCCEED != (ret = zbx_tcp_send_ext(sock, buffer, buffer_size, reserved, sock->protocol,
-				CONFIG_TIMEOUT)))
-		{
-			strscpy(error, zbx_socket_strerror());
-		}
-	}
+	if (SUCCEED != zbx_tcp_send_ext(sock, json.buffer, json.buffer_size, sock->protocol, CONFIG_TIMEOUT))
+		strscpy(error, zbx_socket_strerror());
 	else
-	{
-		if (SUCCEED != (ret = zbx_tcp_send_ext(sock, json.buffer, json.buffer_size, 0, sock->protocol,
-				CONFIG_TIMEOUT)))
-		{
-			strscpy(error, zbx_socket_strerror());
-		}
-	}
+		ret = SUCCEED;
 
 	zbx_json_free(&json);
 
@@ -816,7 +764,6 @@ out:
 
 	zbx_free(host_metadata);
 	zbx_free(interface);
-	zbx_free(buffer);
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
 
