@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@
 static int	execute_remote_script(zbx_script_t *script, DC_HOST *host, char **info, char *error,
 		size_t max_error_len)
 {
-	int		time_start;
+	int		ret = FAIL, time_start;
 	zbx_uint64_t	taskid;
 	DB_RESULT	result = NULL;
 	DB_ROW		row;
@@ -62,8 +62,6 @@ static int	execute_remote_script(zbx_script_t *script, DC_HOST *host, char **inf
 
 		if (NULL != (row = DBfetch(result)))
 		{
-			int	ret;
-
 			if (SUCCEED == (ret = atoi(row[0])))
 				*info = zbx_strdup(*info, row[1]);
 			else
@@ -147,6 +145,54 @@ static void	auditlog_global_script(zbx_uint64_t scriptid, zbx_uint64_t hostid, z
 	while (ZBX_DB_DOWN == DBcommit());
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Function: zbx_check_user_administration_permissions                        *
+ *                                                                            *
+ * Purpose: check if the user has specific or default access for              *
+ *          administration actions                                            *
+ *                                                                            *
+ * Return value:  SUCCEED - the access is granted                             *
+ *                FAIL    - the access is denied                              *
+ *                                                                            *
+ ******************************************************************************/
+static int	zbx_check_user_administration_actions_permissions(zbx_user_t *user, const char *role_rule)
+{
+	int		ret = FAIL;
+	DB_RESULT	result;
+	DB_ROW		row;
+
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() userid:" ZBX_FS_UI64 , __func__, user->userid);
+
+	result = DBselect("select value_int,name from role_rule where roleid=" ZBX_FS_UI64
+			" and (name='%s' or name='%s')", user->roleid, role_rule,
+			ZBX_USER_ROLE_PERMISSION_ACTIONS_DEFAULT_ACCESS);
+
+	while (NULL != (row = DBfetch(result)))
+	{
+		if (0 == strcmp(role_rule, row[1]))
+		{
+			if (ROLE_PERM_ALLOW == atoi(row[0]))
+				ret = SUCCEED;
+			else
+				ret = FAIL;
+			break;
+		}
+		else if (0 == strcmp(ZBX_USER_ROLE_PERMISSION_ACTIONS_DEFAULT_ACCESS, row[1]))
+		{
+			if (ROLE_PERM_ALLOW == atoi(row[0]))
+				ret = SUCCEED;
+		}
+		else
+			THIS_SHOULD_NEVER_HAPPEN;
+	}
+	DBfree_result(result);
+
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_result_string(ret));
+
+	return ret;
+}
+
 /******************************************************************************
  *                                                                            *
  * Function: execute_script                                                   *
@@ -183,6 +229,13 @@ static int	execute_script(zbx_uint64_t scriptid, zbx_uint64_t hostid, const char
 		goto fail;
 	}
 
+	if (SUCCEED != (rc = zbx_check_user_administration_actions_permissions(&user,
+			ZBX_USER_ROLE_PERMISSION_ACTIONS_EXECUTE_SCRIPTS)))
+	{
+		zbx_strlcpy(error, "Permission denied. No role access.", sizeof(error));
+		goto fail;
+	}
+
 	zbx_script_init(&script);
 
 	script.type = ZBX_SCRIPT_TYPE_GLOBAL_SCRIPT;
