@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -1110,7 +1110,7 @@ static void	active_passive_misconfig(zbx_socket_t *sock)
 	zbx_free(msg);
 }
 
-static int	process_trap(zbx_socket_t *sock, char *s, ssize_t bytes_received, zbx_timespec_t *ts)
+static int	process_trap(zbx_socket_t *sock, char *s, zbx_timespec_t *ts)
 {
 	int	ret = SUCCEED;
 
@@ -1131,43 +1131,32 @@ static int	process_trap(zbx_socket_t *sock, char *s, ssize_t bytes_received, zbx
 			return FAIL;
 		}
 
-		if (SUCCEED != zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_REQUEST, value, sizeof(value), NULL))
-			return FAIL;
-
-		if (0 == strcmp(value, ZBX_PROTO_VALUE_PROXY_CONFIG))
+		if (SUCCEED == zbx_json_value_by_name(&jp, ZBX_PROTO_TAG_REQUEST, value, sizeof(value), NULL))
 		{
-			if (0 != (program_type & ZBX_PROGRAM_TYPE_SERVER))
+			if (0 == strcmp(value, ZBX_PROTO_VALUE_PROXY_CONFIG))
 			{
-				send_proxyconfig(sock, &jp);
+				if (0 != (program_type & ZBX_PROGRAM_TYPE_SERVER))
+				{
+					send_proxyconfig(sock, &jp);
+				}
+				else if (0 != (program_type & ZBX_PROGRAM_TYPE_PROXY_PASSIVE))
+				{
+					zabbix_log(LOG_LEVEL_WARNING, "received configuration data from server"
+							" at \"%s\", datalen " ZBX_FS_SIZE_T,
+							sock->peer, (zbx_fs_size_t)(jp.end - jp.start + 1));
+					recv_proxyconfig(sock, &jp);
+				}
+				else if (0 != (program_type & ZBX_PROGRAM_TYPE_PROXY_ACTIVE))
+				{
+					/* This is a misconfiguration: the proxy is configured in active mode */
+					/* but server sends requests to it as to a proxy in passive mode. To  */
+					/* prevent logging of this problem for every request we report it     */
+					/* only when the server sends configuration to the proxy and ignore   */
+					/* it for other requests.                                             */
+					active_passive_misconfig(sock);
+				}
 			}
-			else if (0 != (program_type & ZBX_PROGRAM_TYPE_PROXY_PASSIVE))
-			{
-				zabbix_log(LOG_LEVEL_WARNING, "received configuration data from server"
-						" at \"%s\", datalen " ZBX_FS_SIZE_T,
-						sock->peer, (zbx_fs_size_t)(jp.end - jp.start + 1));
-				recv_proxyconfig(sock, &jp);
-			}
-			else if (0 != (program_type & ZBX_PROGRAM_TYPE_PROXY_ACTIVE))
-			{
-				/* This is a misconfiguration: the proxy is configured in active mode */
-				/* but server sends requests to it as to a proxy in passive mode. To  */
-				/* prevent logging of this problem for every request we report it     */
-				/* only when the server sends configuration to the proxy and ignore   */
-				/* it for other requests.                                             */
-				active_passive_misconfig(sock);
-			}
-		}
-		else
-		{
-			if (ZBX_GIBIBYTE < bytes_received)
-			{
-				zabbix_log(LOG_LEVEL_WARNING, "message size " ZBX_FS_I64 " exceeds the maximum size "
-						ZBX_FS_UI64 " for request \"%s\" received from \"%s\"", bytes_received,
-						(zbx_uint64_t)ZBX_GIBIBYTE, value, sock->peer);
-				return FAIL;
-			}
-
-			if (0 == strcmp(value, ZBX_PROTO_VALUE_AGENT_DATA))
+			else if (0 == strcmp(value, ZBX_PROTO_VALUE_AGENT_DATA))
 			{
 				recv_agenthistory(sock, &jp, ts);
 			}
@@ -1236,10 +1225,7 @@ static int	process_trap(zbx_socket_t *sock, char *s, ssize_t bytes_received, zbx
 					zbx_trapper_item_test(sock, &jp);
 			}
 			else
-			{
-				zabbix_log(LOG_LEVEL_WARNING, "unknown request received from \"%s\": [%s]", sock->peer,
-						value);
-			}
+				zabbix_log(LOG_LEVEL_WARNING, "unknown request received from \"%s\": [%s]", sock->peer, value);
 		}
 	}
 	else if (0 == strncmp(s, "ZBX_GET_ACTIVE_CHECKS", 21))	/* request for list of active checks */
@@ -1254,17 +1240,9 @@ static int	process_trap(zbx_socket_t *sock, char *s, ssize_t bytes_received, zbx
 					key[ITEM_KEY_LEN * ZBX_MAX_BYTES_IN_UTF8_CHAR + 1];
 		zbx_agent_value_t	av;
 		zbx_host_key_t		hk = {host, key};
-		zbx_history_recv_item_t	item;
+		DC_ITEM			item;
 		int			errcode;
 
-		if (ZBX_GIBIBYTE < bytes_received)
-		{
-			zabbix_log(LOG_LEVEL_WARNING, "message size " ZBX_FS_I64 " exceeds the maximum size "
-					ZBX_FS_UI64 " for XML protocol received from \"%s\"", bytes_received,
-					(zbx_uint64_t)ZBX_GIBIBYTE, sock->peer);
-			return FAIL;
-		}
-
 		memset(&av, 0, sizeof(zbx_agent_value_t));
 
 		if ('<' == *s)	/* XML protocol */
@@ -1309,8 +1287,9 @@ static int	process_trap(zbx_socket_t *sock, char *s, ssize_t bytes_received, zbx
 		if (0 == strcmp(av.value, ZBX_NOTSUPPORTED))
 			av.state = ITEM_STATE_NOTSUPPORTED;
 
-		zbx_dc_config_history_recv_get_items_by_keys(&item, &hk, &errcode, 1);
+		DCconfig_get_items_by_keys(&item, &hk, &errcode, 1);
 		process_history_data(&item, &av, &errcode, 1, NULL);
+		DCconfig_clean_items(&item, &errcode, 1);
 
 		zbx_alarm_on(CONFIG_TIMEOUT);
 		if (SUCCEED != zbx_tcp_send_raw(sock, "OK"))
@@ -1323,12 +1302,10 @@ static int	process_trap(zbx_socket_t *sock, char *s, ssize_t bytes_received, zbx
 
 static void	process_trapper_child(zbx_socket_t *sock, zbx_timespec_t *ts)
 {
-	ssize_t	bytes_received;
-
-	if (FAIL == (bytes_received = zbx_tcp_recv_ext(sock, CONFIG_TRAPPER_TIMEOUT, ZBX_TCP_LARGE)))
+	if (SUCCEED != zbx_tcp_recv_to(sock, CONFIG_TRAPPER_TIMEOUT))
 		return;
 
-	process_trap(sock, sock->buffer, bytes_received, ts);
+	process_trap(sock, sock->buffer, ts);
 }
 
 static void	zbx_trapper_sigusr_handler(int flags)
@@ -1357,6 +1334,9 @@ ZBX_THREAD_ENTRY(trapper_thread, args)
 	update_selfmon_counter(ZBX_PROCESS_STATE_BUSY);
 
 	memcpy(&s, (zbx_socket_t *)((zbx_thread_args_t *)args)->args, sizeof(zbx_socket_t));
+#ifdef HAVE_NETSNMP
+	zbx_init_snmp();
+#endif
 
 #if defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
 	zbx_tls_init_child();
@@ -1366,6 +1346,13 @@ ZBX_THREAD_ENTRY(trapper_thread, args)
 
 	DBconnect(ZBX_DB_CONNECT_NORMAL);
 
+	/* configuration sync is performed by trappers on passive Zabbix proxy */
+	if (1 == process_num && 0 == CONFIG_CONFSYNCER_FORKS)
+	{
+		zbx_setproctitle("%s [syncing configuration]", get_process_type_string(process_type));
+		DCsync_configuration(ZBX_DBSYNC_INIT, NULL);
+	}
+
 	zbx_set_sigusr_handler(zbx_trapper_sigusr_handler);
 
 	while (ZBX_IS_RUNNING())
