@@ -26,7 +26,7 @@ $page['title'] = _('Configuration of hosts');
 $page['file'] = 'hosts.php';
 $page['type'] = detect_page_type(PAGE_TYPE_HTML);
 $page['scripts'] = ['multiselect.js', 'textareaflexible.js', 'class.cviewswitcher.js', 'class.cverticalaccordion.js',
-	'inputsecret.js', 'macrovalue.js'
+	'inputsecret.js', 'macrovalue.js', 'class.tab-indicators.js'
 ];
 
 require_once dirname(__FILE__).'/include/page_header.php';
@@ -55,9 +55,7 @@ $fields = [
 	'status' =>					[T_ZBX_INT, O_OPT, null,
 									IN([HOST_STATUS_MONITORED, HOST_STATUS_NOT_MONITORED]), null
 								],
-	'interfaces' =>				[T_ZBX_STR, O_OPT, null,			NOT_EMPTY,
-									'isset({add}) || isset({update})'
-								],
+	'interfaces' =>				[T_ZBX_STR, O_OPT, null,			null,		null],
 	'mainInterfaces' =>			[T_ZBX_INT, O_OPT, null,			DB_ID,		null],
 	'tags' =>					[T_ZBX_STR, O_OPT, null,			null,		null],
 	'mass_update_tags' =>		[T_ZBX_INT, O_OPT, null,
@@ -329,7 +327,7 @@ elseif (hasRequest('hostid') && (hasRequest('clone') || hasRequest('full_clone')
 		$interfaceid = 1;
 		foreach ($_REQUEST['interfaces'] as &$interface) {
 			$interface['interfaceid'] = (string) $interfaceid++;
-			unset($interface['locked'], $interface['items']);
+			unset($interface['items']);
 		}
 		unset($interface);
 	}
@@ -349,7 +347,7 @@ elseif (hasRequest('hostid') && (hasRequest('clone') || hasRequest('full_clone')
 		$msg = [
 			'type' => 'error',
 			'message' => _('The cloned host contains user defined macros with type "Secret text". The value and type of these macros were reset.'),
-			'src' => ''
+			'source' => ''
 		];
 
 		echo makeMessageBox(false, [$msg], null, true, false)->addClass(ZBX_STYLE_MSG_WARNING);
@@ -368,7 +366,7 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 
 		// filter only normal and discovery created hosts
 		$options = [
-			'output' => ['hostid', 'inventory_mode', 'flags'],
+			'output' => ['hostid', 'inventory_mode'],
 			'hostids' => $hostids,
 			'filter' => ['flags' => [ZBX_FLAG_DISCOVERY_NORMAL, ZBX_FLAG_DISCOVERY_CREATED]]
 		];
@@ -534,11 +532,7 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 				}
 			}
 
-			/*
-			 * Inventory mode cannot be changed for discovered hosts. If discovered host has disabled inventory mode,
-			 * inventory values also cannot be changed.
-			 */
-			if (array_key_exists('inventory_mode', $new_values) && $host['flags'] != ZBX_FLAG_DISCOVERY_CREATED) {
+			if (array_key_exists('inventory_mode', $new_values)) {
 				$host['inventory'] = $host_inventory;
 			}
 			elseif ($host['inventory_mode'] != HOST_INVENTORY_DISABLED) {
@@ -656,15 +650,6 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 			unset($host['parentTemplates']);
 
 			$host = $new_values + $host;
-
-			/*
-			 * API prevents changing host inventory_mode for discovered hosts. However, inventory values can still be
-			 * updated if inventory mode allows it.
-			 */
-			if ($host['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
-				unset($host['inventory_mode']);
-			}
-			unset($host['flags']);
 		}
 		unset($host);
 
@@ -760,16 +745,10 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			$interfaces = getRequest('interfaces', []);
 
 			foreach ($interfaces as $key => $interface) {
-				if (zbx_empty($interface['ip']) && zbx_empty($interface['dns'])) {
-					unset($interface[$key]);
-					continue;
-				}
-
 				// Process SNMP interface fields.
 				if ($interface['type'] == INTERFACE_TYPE_SNMP) {
 					if (!array_key_exists('details', $interface)) {
-						unset($interface[$key]);
-						continue;
+						$interface['details'] = [];
 					}
 
 					$interfaces[$key]['details']['bulk'] = array_key_exists('bulk', $interface['details'])
@@ -787,7 +766,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 
 			$mainInterfaces = getRequest('mainInterfaces', []);
 			foreach ([INTERFACE_TYPE_AGENT, INTERFACE_TYPE_SNMP, INTERFACE_TYPE_JMX, INTERFACE_TYPE_IPMI] as $type) {
-				if (array_key_exists($type, $mainInterfaces)) {
+				if (array_key_exists($type, $mainInterfaces) && array_key_exists($mainInterfaces[$type], $interfaces)) {
 					$interfaces[$mainInterfaces[$type]]['main'] = INTERFACE_PRIMARY;
 				}
 			}
@@ -1033,8 +1012,6 @@ elseif (hasRequest('hosts') && hasRequest('action') && str_in_array(getRequest('
 /*
  * Display
  */
-$config = select_config();
-
 if (hasRequest('hosts') && (getRequest('action') === 'host.massupdateform' || hasRequest('masssave'))) {
 	$data = [
 		'hosts' => getRequest('hosts'),
@@ -1140,7 +1117,7 @@ elseif (hasRequest('form')) {
 		'show_inherited_macros' => getRequest('show_inherited_macros', 0),
 
 		// Host inventory
-		'inventory_mode' => getRequest('inventory_mode', $config['default_inventory_mode']),
+		'inventory_mode' => getRequest('inventory_mode', CSettingsHelper::get(CSettingsHelper::DEFAULT_INVENTORY_MODE)),
 		'host_inventory' => getRequest('host_inventory', []),
 		'inventory_items' => [],
 
@@ -1182,7 +1159,7 @@ elseif (hasRequest('form')) {
 			$data['visiblename'] = $dbHost['name'];
 			$data['interfaces'] = API::HostInterface()->get([
 				'output' => API_OUTPUT_EXTEND,
-				'selectItems' => ['type'],
+				'selectItems' => ['itemid'],
 				'hostids' => [$data['hostid']],
 				'sortfield' => 'interfaceid'
 			]);
@@ -1208,21 +1185,6 @@ elseif (hasRequest('form')) {
 
 			// Interfaces
 			foreach ($data['interfaces'] as &$interface) {
-				if ($data['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
-					$interface['locked'] = true;
-				}
-				else {
-					// check if interface has items that require specific interface type, if so type cannot be changed
-					$interface['locked'] = false;
-					foreach ($interface['items'] as $item) {
-						$type = itemTypeInterface($item['type']);
-						if ($type !== false && $type != INTERFACE_TYPE_ANY) {
-							$interface['locked'] = true;
-							break;
-						}
-					}
-				}
-
 				$interface['items'] = (bool) $interface['items'];
 			}
 			unset($interface);
@@ -1436,6 +1398,8 @@ elseif (hasRequest('form')) {
 		'add_templates' => array_map('strval', array_keys($data['add_templates']))
 	];
 
+	$data['allowed_ui_conf_templates'] = CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES);
+
 	$hostView = new CView('configuration.host.edit', $data);
 }
 else {
@@ -1489,6 +1453,7 @@ else {
 	}
 
 	// Select hosts.
+	$limit = CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1;
 	$hosts = API::Host()->get([
 		'output' => ['hostid', $sortField],
 		'evaltype' => $filter['evaltype'],
@@ -1497,7 +1462,7 @@ else {
 		'templateids' => $filter['templates'] ? array_keys($filter['templates']) : null,
 		'editable' => true,
 		'sortfield' => $sortField,
-		'limit' => $config['search_limit'] + 1,
+		'limit' => $limit,
 		'search' => [
 			'name' => ($filter['host'] === '') ? null : $filter['host'],
 			'ip' => ($filter['ip'] === '') ? null : $filter['ip'],
@@ -1632,7 +1597,6 @@ else {
 		'filter' => $filter,
 		'sortField' => $sortField,
 		'sortOrder' => $sortOrder,
-		'config' => $config,
 		'templates' => $templates,
 		'maintenances' => $db_maintenances,
 		'writable_templates' => $writable_templates,
@@ -1640,7 +1604,11 @@ else {
 		'proxies_ms' => $proxies_ms,
 		'profileIdx' => 'web.hosts.filter',
 		'active_tab' => CProfile::get('web.hosts.filter.active', 1),
-		'tags' => makeTags($hosts, true, 'hostid', ZBX_TAG_COUNT_DEFAULT, $filter['tags'])
+		'tags' => makeTags($hosts, true, 'hostid', ZBX_TAG_COUNT_DEFAULT, $filter['tags']),
+		'config' => [
+			'max_in_table' => CSettingsHelper::get(CSettingsHelper::MAX_IN_TABLE)
+		],
+		'allowed_ui_conf_templates' => CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES)
 	];
 
 	$hostView = new CView('configuration.host.list', $data);
