@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,6 +24,12 @@
  */
 class CAlert extends CApiService {
 
+	public const ACCESS_RULES = [
+		'get' => [
+			'min_user_type' => USER_TYPE_ZABBIX_USER
+		]
+	];
+
 	protected $tableName = 'alerts';
 	protected $tableAlias = 'a';
 	protected $sortColumns = ['alertid', 'clock', 'eventid', 'status', 'sendto', 'mediatypeid'];
@@ -85,7 +91,6 @@ class CAlert extends CApiService {
 			'selectUsers'				=> null,
 			'selectHosts'				=> null,
 			'countOutput'				=> false,
-			'groupCount'				=> false,
 			'preservekeys'				=> false,
 			'editable'					=> false,
 			'sortfield'					=> '',
@@ -260,10 +265,6 @@ class CAlert extends CApiService {
 			zbx_value2array($options['eventids']);
 
 			$sqlParts['where'][] = dbConditionInt('a.eventid', $options['eventids']);
-
-			if ($options['groupCount']) {
-				$sqlParts['group']['a'] = 'a.eventid';
-			}
 		}
 
 		// actionids
@@ -330,12 +331,7 @@ class CAlert extends CApiService {
 		$dbRes = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($alert = DBfetch($dbRes)) {
 			if ($options['countOutput']) {
-				if ($options['groupCount']) {
-					$result[] = $alert;
-				}
-				else {
-					$result = $alert['rowscount'];
-				}
+				$result = $alert['rowscount'];
 			}
 			else {
 				$result[$alert['alertid']] = $alert;
