@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -298,9 +298,6 @@ class CGraph extends CGraphGeneral {
 				}
 			}
 			else {
-				// Graphs share table with graph prototypes. Therefore remove graph unrelated fields.
-				unset($graph['discover']);
-
 				$result[$graph['graphid']] = $graph;
 			}
 		}
@@ -387,8 +384,7 @@ class CGraph extends CGraphGeneral {
 				'output' => API_OUTPUT_EXTEND,
 				'selectGraphItems' => API_OUTPUT_EXTEND,
 				'preservekeys' => true,
-				'hostids' => $chdHost['hostid'],
-				'nopermissions' => true
+				'hostids' => $chdHost['hostid']
 			]);
 
 			if ($chdGraph = reset($chdGraphs)) {
