@@ -24,6 +24,13 @@
  */
 class CTriggerPrototype extends CTriggerGeneral {
 
+	public const ACCESS_RULES = [
+		'get' => ['min_user_type' => USER_TYPE_ZABBIX_USER],
+		'create' => ['min_user_type' => USER_TYPE_ZABBIX_ADMIN],
+		'update' => ['min_user_type' => USER_TYPE_ZABBIX_ADMIN],
+		'delete' => ['min_user_type' => USER_TYPE_ZABBIX_ADMIN]
+	];
+
 	protected $tableName = 'triggers';
 	protected $tableAlias = 't';
 	protected $sortColumns = ['triggerid', 'description', 'status', 'priority', 'discover'];
@@ -585,12 +592,9 @@ class CTriggerPrototype extends CTriggerGeneral {
 	 * @param string $triggerPrototypes[]['triggerid']
 	 * @param array  $triggerPrototypes[]['dependencies']
 	 * @param string $triggerPrototypes[]['dependencies'][]['triggerid']
-	 * @param bool   $inherited                                           Determines either to check permissions for
-	 *                                                                    added dependencies. Permissions are not
-	 *                                                                    validated for inherited triggers.
 	 */
-	public function addDependencies(array $triggerPrototypes, bool $inherited = false) {
-		$this->validateAddDependencies($triggerPrototypes, $inherited);
+	public function addDependencies(array $triggerPrototypes) {
+		$this->validateAddDependencies($triggerPrototypes);
 
 		$insert = [];
 
@@ -637,7 +641,7 @@ class CTriggerPrototype extends CTriggerGeneral {
 				}
 				unset($childTrigger);
 
-				$this->addDependencies($childTriggers, true);
+				$this->addDependencies($childTriggers);
 			}
 		}
 	}
@@ -649,11 +653,10 @@ class CTriggerPrototype extends CTriggerGeneral {
 	 * @param string $trigger_prototypes[]['triggerid']
 	 * @param array  $trigger_prototypes[]['dependencies']
 	 * @param string $trigger_prototypes[]['dependencies'][]['triggerid']
-	 * @param bool   $inherited
 	 *
 	 * @throws APIException if the given dependencies are invalid.
 	 */
-	protected function validateAddDependencies(array $trigger_prototypes, bool $inherited = false): void {
+	protected function validateAddDependencies(array $trigger_prototypes) {
 		$depTriggerIds = [];
 
 		foreach ($trigger_prototypes as $trigger_prototype) {
@@ -675,19 +678,15 @@ class CTriggerPrototype extends CTriggerGeneral {
 			'output' => ['triggerid'],
 			'selectDiscoveryRule' => ['itemid'],
 			'triggerids' => $depTriggerIds,
-			'nopermissions' => $inherited ? true : null,
 			'preservekeys' => true
 		]);
 
-		$dep_triggerids = array_diff($depTriggerIds, array_keys($depTriggerPrototypes));
-
 		if ($depTriggerPrototypes) {
 			// Get current trigger prototype discovery rules.
 			$dRules = $this->get([
 				'output' => ['triggerid'],
 				'selectDiscoveryRule' => ['itemid'],
 				'triggerids' => zbx_objectValues($trigger_prototypes, 'triggerid'),
-				'nopermissions' => $inherited ? true : null,
 				'preservekeys' => true
 			]);
 
@@ -712,27 +711,20 @@ class CTriggerPrototype extends CTriggerGeneral {
 				}
 			}
 		}
-		elseif (!$dep_triggerids) {
+
+		// Check other dependency IDs if those are normal triggers.
+		$triggers = API::Trigger()->get([
+			'output' => ['triggerid'],
+			'triggerids' => $depTriggerIds,
+			'filter' => [
+				'flags' => [ZBX_FLAG_DISCOVERY_NORMAL]
+			]
+		]);
+
+		if (!$depTriggerPrototypes && !$triggers) {
 			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
 		}
 
-		if ($dep_triggerids && !$inherited) {
-			// Check other dependency IDs if those are normal triggers.
-			$count = API::Trigger()->get([
-				'countOutput' => true,
-				'triggerids' => $dep_triggerids,
-				'filter' => [
-					'flags' => [ZBX_FLAG_DISCOVERY_NORMAL]
-				]
-			]);
-
-			if ($count != count($dep_triggerids)) {
-				self::exception(ZBX_API_ERROR_PERMISSIONS,
-					_('No permissions to referred object or it does not exist!')
-				);
-			}
-		}
-
 		$this->checkDependencies($trigger_prototypes);
 		$this->checkDependencyParents($trigger_prototypes);
 		$this->checkDependencyDuplicates($trigger_prototypes);
