@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -43,6 +43,26 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 			'types' => ['host', 'user'],
 			'method' => 'resolveTexts'
 		],
+		'hostInterfaceDetailsSecurityname' => [
+			'types' => ['user'],
+			'method' => 'resolveTexts'
+		],
+		'hostInterfaceDetailsAuthPassphrase' => [
+			'types' => ['user'],
+			'method' => 'resolveTexts'
+		],
+		'hostInterfaceDetailsPrivPassphrase' => [
+			'types' => ['user'],
+			'method' => 'resolveTexts'
+		],
+		'hostInterfaceDetailsContextName' => [
+			'types' => ['user'],
+			'method' => 'resolveTexts'
+		],
+		'hostInterfaceDetailsCommunity' => [
+			'types' => ['user'],
+			'method' => 'resolveTexts'
+		],
 		'hostInterfacePort' => [
 			'types' => ['user'],
 			'method' => 'resolveTexts'
@@ -360,7 +380,8 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 			'host' => [],
 			'interface' => [],
 			'item' => [],
-			'references' => []
+			'references' => [],
+			'log' => []
 		];
 		$usermacros = [];
 		$macro_values = [];
@@ -369,7 +390,10 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 			'macros_n' => [
 				'host' => ['{HOSTNAME}', '{HOST.HOST}', '{HOST.NAME}'],
 				'interface' => ['{IPADDRESS}', '{HOST.IP}', '{HOST.DNS}', '{HOST.CONN}', '{HOST.PORT}'],
-				'item' => ['{ITEM.LASTVALUE}', '{ITEM.VALUE}']
+				'item' => ['{ITEM.LASTVALUE}', '{ITEM.VALUE}'],
+				'log' => ['{ITEM.LOG.DATE}', '{ITEM.LOG.TIME}', '{ITEM.LOG.AGE}', '{ITEM.LOG.SOURCE}',
+					'{ITEM.LOG.SEVERITY}', '{ITEM.LOG.NSEVERITY}', '{ITEM.LOG.EVENTID}'
+				]
 			],
 			'macro_funcs_n' => [
 				'item' => ['{ITEM.LASTVALUE}', '{ITEM.VALUE}']
@@ -414,6 +438,14 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 					}
 				}
 
+				foreach ($matched_macros['macros_n']['log'] as $token => $data) {
+					$macro_values[$triggerid][$token] = UNRESOLVED_MACRO_STRING;
+
+					if (array_key_exists($data['f_num'], $functionids)) {
+						$macros['log'][$functionids[$data['f_num']]][$data['macro']][] = ['token' => $token];
+					}
+				}
+
 				foreach ($matched_macros['macro_funcs_n']['item'] as $token => $data) {
 					$macro_values[$triggerid][$token] = UNRESOLVED_MACRO_STRING;
 
@@ -447,6 +479,7 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 			$macro_values = $this->getHostMacros($macros['host'], $macro_values);
 			$macro_values = $this->getIpMacros($macros['interface'], $macro_values);
 			$macro_values = $this->getItemMacros($macros['item'], $macro_values);
+			$macro_values = $this->getItemLogMacros($macros['log'], $macro_values);
 
 			if ($usermacros) {
 				// Get hosts for triggers.
@@ -513,7 +546,8 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 		$macros = [
 			'host' => [],
 			'interface' => [],
-			'item' => []
+			'item' => [],
+			'log' => []
 		];
 		$usermacros = [];
 		$macro_values = [];
@@ -522,7 +556,10 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 			'macros_n' => [
 				'host' => ['{HOSTNAME}', '{HOST.HOST}', '{HOST.NAME}'],
 				'interface' => ['{IPADDRESS}', '{HOST.IP}', '{HOST.DNS}', '{HOST.CONN}', '{HOST.PORT}'],
-				'item' => ['{ITEM.LASTVALUE}', '{ITEM.VALUE}']
+				'item' => ['{ITEM.LASTVALUE}', '{ITEM.VALUE}'],
+				'log' => ['{ITEM.LOG.DATE}', '{ITEM.LOG.TIME}', '{ITEM.LOG.AGE}', '{ITEM.LOG.SOURCE}',
+					'{ITEM.LOG.SEVERITY}', '{ITEM.LOG.NSEVERITY}', '{ITEM.LOG.EVENTID}'
+				]
 			],
 			'macro_funcs_n' => [
 				'item' => ['{ITEM.LASTVALUE}', '{ITEM.VALUE}']
@@ -565,6 +602,14 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 				}
 			}
 
+			foreach ($matched_macros['macros_n']['log'] as $token => $data) {
+				$macro_values[$triggerid][$token] = UNRESOLVED_MACRO_STRING;
+
+				if (array_key_exists($data['f_num'], $functionids)) {
+					$macros['log'][$functionids[$data['f_num']]][$data['macro']][] = ['token' => $token];
+				}
+			}
+
 			foreach ($matched_macros['macro_funcs_n']['item'] as $token => $data) {
 				$macro_values[$triggerid][$token] = UNRESOLVED_MACRO_STRING;
 
@@ -586,6 +631,7 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 		$macro_values = $this->getHostMacros($macros['host'], $macro_values);
 		$macro_values = $this->getIpMacros($macros['interface'], $macro_values);
 		$macro_values = $this->getItemMacros($macros['item'], $macro_values, $triggers, $options);
+		$macro_values = $this->getItemLogMacros($macros['log'], $macro_values);
 
 		if ($usermacros) {
 			// Get hosts for triggers.
@@ -669,7 +715,8 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 			'host' => [],
 			'interface' => [],
 			'item' => [],
-			'event' => []
+			'event' => [],
+			'log' => []
 		];
 		$usermacros = [];
 		$macro_values = [];
@@ -682,7 +729,10 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 			'macros_n' => [
 				'host' => ['{HOST.ID}', '{HOST.HOST}', '{HOST.NAME}'],
 				'interface' => ['{HOST.IP}', '{HOST.DNS}', '{HOST.CONN}', '{HOST.PORT}'],
-				'item' => ['{ITEM.LASTVALUE}', '{ITEM.VALUE}']
+				'item' => ['{ITEM.LASTVALUE}', '{ITEM.VALUE}'],
+				'log' => ['{ITEM.LOG.DATE}', '{ITEM.LOG.TIME}', '{ITEM.LOG.AGE}', '{ITEM.LOG.SOURCE}',
+					'{ITEM.LOG.SEVERITY}', '{ITEM.LOG.NSEVERITY}', '{ITEM.LOG.EVENTID}'
+				]
 			],
 			'macro_funcs_n' => [
 				'item' => ['{ITEM.LASTVALUE}', '{ITEM.VALUE}']
@@ -731,6 +781,14 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 			}
 		}
 
+		foreach ($matched_macros['macros_n']['log'] as $token => $data) {
+			$macro_values[$triggerid][$token] = UNRESOLVED_MACRO_STRING;
+
+			if (array_key_exists($data['f_num'], $functionids)) {
+				$macros['log'][$functionids[$data['f_num']]][$data['macro']][] = ['token' => $token];
+			}
+		}
+
 		foreach ($matched_macros['macro_funcs_n']['item'] as $token => $data) {
 			$macro_values[$triggerid][$token] = UNRESOLVED_MACRO_STRING;
 
@@ -751,6 +809,7 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 		$macro_values = $this->getHostMacros($macros['host'], $macro_values);
 		$macro_values = $this->getIpMacros($macros['interface'], $macro_values);
 		$macro_values = $this->getItemMacros($macros['item'], $macro_values);
+		$macro_values = $this->getItemLogMacros($macros['log'], $macro_values);
 
 		if ($usermacros) {
 			// Get hosts for triggers.
@@ -981,19 +1040,25 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 									$link = (new CSpan($function['host'].':'.$function['key_']))->addClass($style);
 								}
 								elseif ($function['flags'] == ZBX_FLAG_DISCOVERY_PROTOTYPE) {
-									$link = (new CLink($function['host'].':'.$function['key_'],
-										'disc_prototypes.php?form=update&itemid='.$function['itemid'].
-										'&parent_discoveryid='.$function['parent_itemid']
-									))
-										->addClass(ZBX_STYLE_LINK_ALT)
-										->addClass($style);
+									$link = CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_HOSTS)
+										? (new CLink($function['host'].':'.$function['key_'],
+											'disc_prototypes.php?form=update&itemid='.$function['itemid'].
+											'&parent_discoveryid='.$function['parent_itemid']
+										))
+											->addClass(ZBX_STYLE_LINK_ALT)
+											->addClass($style)
+										: (new CSpan($function['host'].':'.$function['key_']))
+											->addClass($style);
 								}
 								else {
-									$link = (new CLink($function['host'].':'.$function['key_'],
+									$link = CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_HOSTS)
+									? (new CLink($function['host'].':'.$function['key_'],
 										'items.php?form=update&itemid='.$function['itemid']
 									))
 										->addClass(ZBX_STYLE_LINK_ALT)
 										->setAttribute('data-itemid', $function['itemid'])
+										->addClass($style)
+									: (new CSpan($function['host'].':'.$function['key_']))
 										->addClass($style);
 								}
 
@@ -1631,6 +1696,41 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 		return $items;
 	}
 
+	/**
+	 * Resolve macros in item description.
+	 *
+	 * @param array  $items
+	 * @param string $items[n]['hostid']
+	 * @param string $items[n]['description']
+	 *
+	 * @return array
+	 */
+	public function resolveItemDescriptions(array $items): array {
+		$types = ['usermacros' => true];
+		$macro_values = [];
+		$usermacros = [];
+
+		foreach ($items as $key => $item) {
+			$matched_macros = self::extractMacros([$item['description']], $types);
+
+			if ($matched_macros['usermacros']) {
+				$usermacros[$key] = ['hostids' => [$item['hostid']], 'macros' => $matched_macros['usermacros']];
+			}
+		}
+
+		foreach ($this->getUserMacros($usermacros) as $key => $usermacros_data) {
+			$macro_values[$key] = array_key_exists($key, $macro_values)
+				? array_merge($macro_values[$key], $usermacros_data['macros'])
+				: $usermacros_data['macros'];
+		}
+
+		foreach ($macro_values as $key => $macro_value) {
+			$items[$key]['description'] = strtr($items[$key]['description'], $macro_value);
+		}
+
+		return $items;
+	}
+
 	/**
 	 * Resolve item delay macros, item history and item trend macros.
 	 *
@@ -2339,19 +2439,19 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 
 					case 'HOST.IP':
 					case 'IPADDRESS': // deprecated
-						if ($host) {
+						if ($host && $host['interface']) {
 							$matched_macro['value'] = $host['interface']['ip'];
 						}
 						break;
 
 					case 'HOST.DNS':
-						if ($host) {
+						if ($host && $host['interface']) {
 							$matched_macro['value'] = $host['interface']['dns'];
 						}
 						break;
 
 					case 'HOST.CONN':
-						if ($host) {
+						if ($host && $host['interface']) {
 							$matched_macro['value'] = $host['interface']['conn'];
 						}
 						break;
@@ -2662,7 +2762,8 @@ class CMacrosResolver extends CMacrosResolverGeneral {
 	 * @param array  $data['texts_support_macros']               List of texts potentially could contain macros.
 	 * @param array  $data['texts_support_user_macros']          List of texts potentially could contain user macros.
 	 * @param array  $data['texts_support_lld_macros']           List of texts potentially could contain LLD macros.
-	 * @param int    $data['hostids']                            Hostid for which tested item belongs to.
+	 * @param int    $data['hostid']                             Hostid for which tested item belongs to.
+	 * @param array  $data['macros_values']                      Values for supported macros.
 	 *
 	 * @return array
 	 */
