@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,21 +18,18 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
-define('ZABBIX_VERSION',		'5.0.23');
-define('ZABBIX_API_VERSION',	'5.0.23');
-define('ZABBIX_EXPORT_VERSION',	'5.0');
-define('ZABBIX_DB_VERSION',		5000000);
+define('ZABBIX_VERSION',		'5.2.7');
+define('ZABBIX_API_VERSION',	'5.2.7');
+define('ZABBIX_EXPORT_VERSION',	'5.2');
+define('ZABBIX_DB_VERSION',		5020000);
 
 define('ZABBIX_COPYRIGHT_FROM',	'2001');
-define('ZABBIX_COPYRIGHT_TO',	'2022');
-
-define('ZBX_LOGIN_ATTEMPTS',	5);
-define('ZBX_LOGIN_BLOCK',		30); // sec
+define('ZABBIX_COPYRIGHT_TO',	'2021');
 
 define('ZBX_BCRYPT_COST',		10);
 define('ZBX_MD5_SIZE',			32);
 
-define('ZBX_SESSION_NAME', 'zbx_sessionid'); // Session cookie name for Zabbix front-end.
+define('ZBX_SESSION_NAME', 'zbx_session'); // Session cookie name for Zabbix front-end.
 
 define('ZBX_KIBIBYTE',	'1024');
 define('ZBX_MEBIBYTE',	'1048576');
@@ -40,9 +37,7 @@ define('ZBX_GIBIBYTE',	'1073741824');
 define('ZBX_TEBIBYTE',	'1099511627776');
 
 define('ZBX_MIN_PERIOD',		60); // 1 minute
-// The maximum period for the time bar control, ~2 years (2 * 365 * 86400) + 86400 + 3600 + 1.
-// Both dates are included to the period, so one second is needed to cover the case from "now" till "now-2y".
-define('ZBX_MAX_PERIOD',		63162001);
+
 define('ZBX_MIN_INT32',			-2147483648);
 define('ZBX_MAX_INT32',			2147483647);
 define('ZBX_MAX_UINT64',		'18446744073709551615');
@@ -53,22 +48,17 @@ define('ZBX_FLOAT_MIN', PHP_FLOAT_MIN);
 define('ZBX_FLOAT_MAX', PHP_FLOAT_MAX);
 
 define('ZBX_MAX_DATE',			ZBX_MAX_INT32); // 19 Jan 2038 05:14:07
-define('ZBX_PERIOD_DEFAULT_FROM',	'now-1h'); // Default time interval.
-define('ZBX_PERIOD_DEFAULT_TO',		'now');
 define('ZBX_MIN_TIMESHIFT',	-788400000); // Min valid timeshift value in seconds (25 years).
 define('ZBX_MAX_TIMESHIFT',	788400000); // Max valid timeshift value in seconds (25 years).
 
-// Applied to tables with variable count of columns. Columns above this limit will be truncated.
-define('ZBX_MAX_TABLE_COLUMNS', 50);
 define('ZBX_MAX_GRAPHS_PER_PAGE', 20);
 
 // Date and time format separators must be synced with setSDateFromOuterObj() in class.calendar.js.
 define('ZBX_FULL_DATE_TIME',	'Y-m-d H:i:s'); // Time selector full date and time presentation format.
 define('ZBX_DATE_TIME',			'Y-m-d H:i'); // Time selector date and time without seconds presentation format.
 
-// the maximum period to display history data for the latest data and item overview pages in seconds
-// by default set to 86400 seconds (24 hours)
-define('ZBX_HISTORY_PERIOD', 86400);
+// TTL timeout in seconds used to invalidate data cache of Vault response. Set 0 to disable Vault response caching.
+define('ZBX_DATA_CACHE_TTL', 60);
 
 define('ZBX_HISTORY_SOURCE_ELASTIC',	'elastic');
 define('ZBX_HISTORY_SOURCE_SQL',		'sql');
@@ -146,16 +136,16 @@ define('ZBX_DB_MAX_ID', '9223372036854775807');
 define('ZBX_DB_MAX_INSERTS', 10000);
 
 // Default db and field character set (MYSQL & POSTGRESQL)
-define('ZBX_DB_POSTGRESQL_ALLOWED_CHARSET', 'UTF8');
-define('ZBX_DB_MYSQL_ALLOWED_CHARSETS', ['UTF8', 'UTF8MB3']);
-define('ZBX_DB_MYSQL_ALLOWED_COLLATIONS', ['utf8_bin', 'utf8mb3_bin']);
+define('ZBX_DB_DEFAULT_CHARSET', 'UTF8');
+define('ZBX_DB_MYSQL_DEFAULT_COLLATION', 'utf8_bin');
 
 // Default db defines for Oracle DB
 define('ORACLE_MAX_STRING_SIZE', 4000);
 define('ORACLE_UTF8_CHARSET', 'AL32UTF8');
 define('ORACLE_CESU8_CHARSET', 'UTF8');
 
-define('ZBX_SHOW_TECHNICAL_ERRORS', false);
+define('DB_STORE_CREDS_CONFIG', 0);
+define('DB_STORE_CREDS_VAULT', 1);
 
 define('PAGE_TYPE_HTML',				0);
 define('PAGE_TYPE_IMAGE',				1);
@@ -189,10 +179,6 @@ define('P_NZERO',				0x0020);
 define('P_NO_TRIM',				0x0040);
 define('P_ALLOW_USER_MACRO',	0x0080);
 define('P_ALLOW_LLD_MACRO',		0x0100);
-define('ZBX_URI_VALID_SCHEMES', 'http,https,ftp,file,mailto,tel,ssh');
-
-// Validate URI against schemes whitelist defined in ZBX_URI_VALID_SCHEMES.
-define('VALIDATE_URI_SCHEMES', true);
 
 //	misc parameters
 define('IMAGE_FORMAT_PNG',	'PNG');
@@ -228,7 +214,7 @@ define('AUDIT_ACTION_DISABLE',	6);
 define('AUDIT_ACTION_EXECUTE',	7);
 
 define('AUDIT_RESOURCE_USER',				0);
-define('AUDIT_RESOURCE_ZABBIX_CONFIG',		2);
+define('AUDIT_RESOURCE_ZABBIX_CONFIG',		2); // Currently not used but need for compatibility with old audit records.
 define('AUDIT_RESOURCE_MEDIA_TYPE',			3);
 define('AUDIT_RESOURCE_HOST',				4);
 define('AUDIT_RESOURCE_ACTION',				5);
@@ -262,6 +248,11 @@ define('AUDIT_RESOURCE_ITEM_PROTOTYPE',		36);
 define('AUDIT_RESOURCE_HOST_PROTOTYPE',		37);
 define('AUDIT_RESOURCE_AUTOREGISTRATION',	38);
 define('AUDIT_RESOURCE_MODULE',				39);
+define('AUDIT_RESOURCE_SETTINGS',			40);
+define('AUDIT_RESOURCE_HOUSEKEEPING',		41);
+define('AUDIT_RESOURCE_AUTHENTICATION',		42);
+define('AUDIT_RESOURCE_TEMPLATE_DASHBOARD',	43);
+define('AUDIT_RESOURCE_USER_ROLE',			44);
 
 define('CONDITION_TYPE_HOST_GROUP',			0);
 define('CONDITION_TYPE_HOST',				1);
@@ -356,6 +347,9 @@ define('INTERFACE_TYPE_SNMP',		2);
 define('INTERFACE_TYPE_IPMI',		3);
 define('INTERFACE_TYPE_JMX',		4);
 
+define('HOST_PROT_INTERFACES_INHERIT',	0);
+define('HOST_PROT_INTERFACES_CUSTOM',	1);
+
 define('SNMP_BULK_DISABLED',	0);
 define('SNMP_BULK_ENABLED',		1);
 
@@ -497,6 +491,7 @@ define('ITEM_TYPE_SNMPTRAP',		17);
 define('ITEM_TYPE_DEPENDENT',		18);
 define('ITEM_TYPE_HTTPAGENT',		19);
 define('ITEM_TYPE_SNMP',			20);
+define('ITEM_TYPE_SCRIPT',			21);
 
 define('SNMP_V1', 1);
 define('SNMP_V2C', 2);
@@ -568,31 +563,32 @@ define('ITEM_DELAY_FLEXIBLE',	0);
 define('ITEM_DELAY_SCHEDULING',	1);
 
 // Item pre-processing types.
-define('ZBX_PREPROC_MULTIPLIER',			1);
-define('ZBX_PREPROC_RTRIM',					2);
-define('ZBX_PREPROC_LTRIM',					3);
-define('ZBX_PREPROC_TRIM',					4);
-define('ZBX_PREPROC_REGSUB',				5);
-define('ZBX_PREPROC_BOOL2DEC',				6);
-define('ZBX_PREPROC_OCT2DEC',				7);
-define('ZBX_PREPROC_HEX2DEC',				8);
-define('ZBX_PREPROC_DELTA_VALUE',			9);
-define('ZBX_PREPROC_DELTA_SPEED',			10);
-define('ZBX_PREPROC_XPATH',					11);
-define('ZBX_PREPROC_JSONPATH',				12);
-define('ZBX_PREPROC_VALIDATE_RANGE',		13);
-define('ZBX_PREPROC_VALIDATE_REGEX',		14);
-define('ZBX_PREPROC_VALIDATE_NOT_REGEX',	15);
-define('ZBX_PREPROC_ERROR_FIELD_JSON',		16);
-define('ZBX_PREPROC_ERROR_FIELD_XML',		17);
-define('ZBX_PREPROC_ERROR_FIELD_REGEX',		18);
-define('ZBX_PREPROC_THROTTLE_VALUE',		19);
-define('ZBX_PREPROC_THROTTLE_TIMED_VALUE',	20);
-define('ZBX_PREPROC_SCRIPT',				21);
-define('ZBX_PREPROC_PROMETHEUS_PATTERN',	22);
-define('ZBX_PREPROC_PROMETHEUS_TO_JSON',	23);
-define('ZBX_PREPROC_CSV_TO_JSON',			24);
-define('ZBX_PREPROC_STR_REPLACE',			25);
+define('ZBX_PREPROC_MULTIPLIER',				1);
+define('ZBX_PREPROC_RTRIM',						2);
+define('ZBX_PREPROC_LTRIM',						3);
+define('ZBX_PREPROC_TRIM',						4);
+define('ZBX_PREPROC_REGSUB',					5);
+define('ZBX_PREPROC_BOOL2DEC',					6);
+define('ZBX_PREPROC_OCT2DEC',					7);
+define('ZBX_PREPROC_HEX2DEC',					8);
+define('ZBX_PREPROC_DELTA_VALUE',				9);
+define('ZBX_PREPROC_DELTA_SPEED',				10);
+define('ZBX_PREPROC_XPATH',						11);
+define('ZBX_PREPROC_JSONPATH',					12);
+define('ZBX_PREPROC_VALIDATE_RANGE',			13);
+define('ZBX_PREPROC_VALIDATE_REGEX',			14);
+define('ZBX_PREPROC_VALIDATE_NOT_REGEX',		15);
+define('ZBX_PREPROC_ERROR_FIELD_JSON',			16);
+define('ZBX_PREPROC_ERROR_FIELD_XML',			17);
+define('ZBX_PREPROC_ERROR_FIELD_REGEX',			18);
+define('ZBX_PREPROC_THROTTLE_VALUE',			19);
+define('ZBX_PREPROC_THROTTLE_TIMED_VALUE',		20);
+define('ZBX_PREPROC_SCRIPT',					21);
+define('ZBX_PREPROC_PROMETHEUS_PATTERN',		22);
+define('ZBX_PREPROC_PROMETHEUS_TO_JSON',		23);
+define('ZBX_PREPROC_CSV_TO_JSON',				24);
+define('ZBX_PREPROC_STR_REPLACE',				25);
+define('ZBX_PREPROC_VALIDATE_NOT_SUPPORTED',	26);
 
 // Item pre-processing error handlers.
 define('ZBX_PREPROC_FAIL_DEFAULT',			0);
@@ -813,6 +809,8 @@ define('DASHBOARD_MAX_COLUMNS',		24);
 define('DASHBOARD_MAX_ROWS',		64);
 define('DASHBOARD_WIDGET_MIN_ROWS',	2);
 define('DASHBOARD_WIDGET_MAX_ROWS',	32);
+define('DASHBOARD_FILTER_SHOW_ALL',	0);
+define('DASHBOARD_FILTER_SHOW_MY',	1);
 
 // alignments
 define('HALIGN_DEFAULT',	0);
@@ -909,6 +907,7 @@ define('HTTPTEST_AUTH_NONE',		0);
 define('HTTPTEST_AUTH_BASIC',		1);
 define('HTTPTEST_AUTH_NTLM',		2);
 define('HTTPTEST_AUTH_KERBEROS',	3);
+define('HTTPTEST_AUTH_DIGEST',		4);
 
 define('HTTPTEST_STATUS_ACTIVE',	0);
 define('HTTPTEST_STATUS_DISABLED',	1);
@@ -1265,10 +1264,6 @@ define('IPMI_PRIVILEGE_OEM',		5);
 define('ZBX_HAVE_IPV6', true);
 define('ZBX_DISCOVERER_IPRANGE_LIMIT', 65536);
 
-define('ZBX_SOCKET_TIMEOUT',			3);		// Socket timeout limit.
-define('ZBX_CONNECT_TIMEOUT',			3);		// Zabbix server connect timeout limit.
-define('ZBX_MEDIA_TYPE_TEST_TIMEOUT',	65);	// Timeout limit set for media type test.
-define('ZBX_SCRIPT_TIMEOUT',			60);	// Timeout limit set for scripts.
 define('ZBX_SOCKET_BYTES_LIMIT',    ZBX_MEBIBYTE * 16); // socket response size limit
 
 // value is also used in servercheck.js file
@@ -1276,16 +1271,6 @@ define('SERVER_CHECK_INTERVAL', 10);
 
 define('DATE_TIME_FORMAT_SECONDS_XML', 'Y-m-d\TH:i:s\Z');
 
-// XML export|import tags
-define('XML_TAG_MACRO',				'macro');
-define('XML_TAG_HOST',				'host');
-define('XML_TAG_HOSTINVENTORY',		'host_inventory');
-define('XML_TAG_ITEM',				'item');
-define('XML_TAG_TRIGGER',			'trigger');
-define('XML_TAG_GRAPH',				'graph');
-define('XML_TAG_GRAPH_ELEMENT',		'graph_element');
-define('XML_TAG_DEPENDENCY',		'dependency');
-
 define('ZBX_DEFAULT_IMPORT_HOST_GROUP', 'Imported hosts');
 
 // XML import flags
@@ -1340,9 +1325,13 @@ define('API_LLD_MACRO',				29);
 define('API_PSK',					30);
 define('API_SORTORDER',				31);
 define('API_CALC_FORMULA',			32);
-define('API_TRIGGER_EXPRESSION',	33);
-define('API_JSONRPC_PARAMS',		34);
-define('API_JSONRPC_ID',			35);
+define('API_IP',					33);
+define('API_DNS',					34);
+define('API_PORT',					35);
+define('API_TRIGGER_EXPRESSION',	36);
+define('API_EVENT_NAME',			37);
+define('API_JSONRPC_PARAMS',		38);
+define('API_JSONRPC_ID',			39);
 
 // flags
 define('API_REQUIRED',					0x0001);
@@ -1357,6 +1346,7 @@ define('API_REQUIRED_LLD_MACRO',		0x0100);
 define('API_TIME_UNIT_WITH_YEAR',		0x0200);
 define('API_ALLOW_EVENT_TAGS_MACRO',	0x0400);
 define('API_PRESERVE_KEYS',				0x0800);
+define('API_ALLOW_MACRO',				0x1000);
 
 // JSON error codes.
 if (!defined('JSON_ERROR_NONE')) {
@@ -1385,6 +1375,7 @@ define('ZBX_MAX_PORT_NUMBER', 65535);
 
 define('ZBX_MACRO_TYPE_TEXT', 0); // Display macro value as text.
 define('ZBX_MACRO_TYPE_SECRET', 1); // Display masked macro value.
+define('ZBX_MACRO_TYPE_VAULT', 2); // Display macro value as text (path to secret in HashiCorp Vault).
 
 define('ZBX_SECRET_MASK', '******'); // Placeholder for secret values.
 
@@ -1519,14 +1510,24 @@ define('ZBX_VALID_OK',		0);
 define('ZBX_VALID_ERROR',	1);
 define('ZBX_VALID_WARNING',	2);
 
+// user default language
+define('LANG_DEFAULT', 'default');
+
+// the default language
+define('ZBX_DEFAULT_LANG', 'en_GB');
+
+// user default time zone
+define('TIMEZONE_DEFAULT', 'default');
+
+// the default time zone
+define('ZBX_DEFAULT_TIMEZONE', 'system');
+
 // user default theme
 define('THEME_DEFAULT', 'default');
 
 // the default theme
 define('ZBX_DEFAULT_THEME', 'blue-theme');
 
-define('ZBX_DEFAULT_URL', 'zabbix.php?action=dashboard.view');
-
 // date format context, usable for translators
 define('DATE_FORMAT_CONTEXT', 'Date format (see http://php.net/date)');
 
@@ -1544,9 +1545,6 @@ define('QUEUE_OVERVIEW', 0);
 define('QUEUE_OVERVIEW_BY_PROXY', 1);
 define('QUEUE_DETAILS', 2);
 
-// item count to display in the details queue
-define('QUEUE_DETAIL_ITEM_COUNT', 500);
-
 // target types to copy items/triggers/graphs
 define('COPY_TYPE_TO_HOST_GROUP',	0);
 define('COPY_TYPE_TO_HOST',			1);
@@ -1572,6 +1570,39 @@ define('ZBX_POPUP_CONDITION_TYPE_EVENT_CORR', 0);
 define('ZBX_POPUP_CONDITION_TYPE_ACTION', 1);
 define('ZBX_POPUP_CONDITION_TYPE_ACTION_OPERATION', 2);
 
+// Tab indicator names.
+define('TAB_INDICATOR_MACROS', 'macros');
+define('TAB_INDICATOR_LINKED_TEMPLATE', 'linked-template');
+define('TAB_INDICATOR_TAGS', 'tags');
+define('TAB_INDICATOR_AUTH_HTTP', 'http');
+define('TAB_INDICATOR_AUTH_LDAP', 'ldap');
+define('TAB_INDICATOR_AUTH_SAML', 'saml');
+define('TAB_INDICATOR_INVENTORY', 'inventory');
+define('TAB_INDICATOR_ENCRYPTION', 'encryption');
+define('TAB_INDICATOR_GROUPS', 'groups');
+define('TAB_INDICATOR_PREPROCESSING', 'preprocessing');
+define('TAB_INDICATOR_DEPENDENCY', 'dependency');
+define('TAB_INDICATOR_LLD_MACROS', 'lld-macros');
+define('TAB_INDICATOR_FILTERS', 'filters');
+define('TAB_INDICATOR_OVERRIDES', 'overrides');
+define('TAB_INDICATOR_STEPS', 'steps');
+define('TAB_INDICATOR_HTTP_AUTH', 'http-auth');
+define('TAB_INDICATOR_OPERATIONS', 'operations');
+define('TAB_INDICATOR_SERVICE_DEPENDENCY', 'service-dependency');
+define('TAB_INDICATOR_TIME', 'time');
+define('TAB_INDICATOR_TAG_FILTER', 'tag-filter');
+define('TAB_INDICATOR_MEDIA', 'media');
+define('TAB_INDICATOR_MESSAGE_TEMPLATE', 'message-template');
+define('TAB_INDICATOR_FRONTEND_MESSAGE', 'frontend-message');
+define('TAB_INDICATOR_SHARING', 'sharing');
+define('TAB_INDICATOR_GRAPH_DATASET', 'graph-dataset');
+define('TAB_INDICATOR_GRAPH_OPTIONS', 'graph-options');
+define('TAB_INDICATOR_GRAPH_TIME', 'graph-time');
+define('TAB_INDICATOR_GRAPH_LEGEND', 'graph-legend');
+define('TAB_INDICATOR_GRAPH_PROBLEMS', 'graph-problems');
+define('TAB_INDICATOR_GRAPH_OVERRIDES', 'graph-overrides');
+define('TAB_INDICATOR_PERMISSIONS', 'permissions');
+
 // CSS styles
 define('ZBX_STYLE_ACTION_BUTTONS', 'action-buttons');
 define('ZBX_STYLE_ADM_IMG', 'adm-img');
@@ -1583,6 +1614,9 @@ define('ZBX_STYLE_ARROW_UP', 'arrow-up');
 define('ZBX_STYLE_BLUE', 'blue');
 define('ZBX_STYLE_BTN_ADD_FAV', 'btn-add-fav');
 define('ZBX_STYLE_BTN_ALT', 'btn-alt');
+define('ZBX_STYLE_BTN_TOGGLE_CHEVRON', 'btn-toggle-chevron');
+define('ZBX_STYLE_BTN_SPLIT', 'btn-split');
+define('ZBX_STYLE_BTN_TOGGLE', 'btn-dropdown-toggle');
 define('ZBX_STYLE_BTN_BACK_MAP', 'btn-back-map');
 define('ZBX_STYLE_BTN_BACK_MAP_CONTAINER', 'btn-back-map-container');
 define('ZBX_STYLE_BTN_BACK_MAP_CONTENT', 'btn-back-map-content');
@@ -1662,11 +1696,11 @@ define('ZBX_STYLE_TIME_INPUT_ERROR', 'time-input-error');
 define('ZBX_STYLE_TIME_QUICK', 'time-quick');
 define('ZBX_STYLE_TIME_QUICK_RANGE', 'time-quick-range');
 define('ZBX_STYLE_TIME_SELECTION_CONTAINER', 'time-selection-container');
-define('ZBX_STYLE_FILTER_BREADCRUMB', 'filter-breadcrumb');
 define('ZBX_STYLE_FILTER_BTN_CONTAINER', 'filter-btn-container');
 define('ZBX_STYLE_FILTER_CONTAINER', 'filter-container');
 define('ZBX_STYLE_FILTER_HIGHLIGHT_ROW_CB', 'filter-highlight-row-cb');
 define('ZBX_STYLE_FILTER_FORMS', 'filter-forms');
+define('ZBX_STYLE_FILTER_SPACE', 'filter-space');
 define('ZBX_STYLE_FILTER_TRIGGER', 'filter-trigger');
 define('ZBX_STYLE_FLH_AVERAGE_BG', 'flh-average-bg');
 define('ZBX_STYLE_FLH_DISASTER_BG', 'flh-disaster-bg');
@@ -1685,6 +1719,7 @@ define('ZBX_STYLE_GREY', 'grey');
 define('ZBX_STYLE_TEAL', 'teal');
 define('ZBX_STYLE_HEADER_TITLE', 'header-title');
 define('ZBX_STYLE_HEADER_CONTROLS', 'header-controls');
+define('ZBX_STYLE_HEADER_Z_SELECT', 'header-z-select');
 define('ZBX_STYLE_HIGH_BG', 'high-bg');
 define('ZBX_STYLE_HOR_LIST', 'hor-list');
 define('ZBX_STYLE_HOVER_NOBG', 'hover-nobg');
@@ -1696,7 +1731,7 @@ define('ZBX_STYLE_ICON_DEPEND_UP', 'icon-depend-up');
 define('ZBX_STYLE_ICON_DESCRIPTION', 'icon-description');
 define('ZBX_STYLE_ICON_INFO', 'icon-info');
 define('ZBX_STYLE_ICON_INVISIBLE', 'icon-invisible');
-define('ZBX_STYLE_ICON_MAINTENANCE', 'icon-maintenance');
+define('ZBX_STYLE_ICON_MAINT', 'icon-maint');
 define('ZBX_STYLE_ICON_WZRD_ACTION', 'icon-wzrd-action');
 define('ZBX_STYLE_ACTION_COMMAND', 'icon-action-command');
 define('ZBX_STYLE_ACTION_ICON_CLOSE', 'icon-action-close');
@@ -1761,7 +1796,6 @@ define('ZBX_STYLE_OVERLAY_CLOSE_BTN', 'overlay-close-btn');
 define('ZBX_STYLE_OVERLAY_DESCR', 'overlay-descr');
 define('ZBX_STYLE_OVERLAY_DESCR_URL', 'overlay-descr-url');
 define('ZBX_STYLE_OVERFLOW_ELLIPSIS', 'overflow-ellipsis');
-define('ZBX_STYLE_OBJECT_GROUP', 'object-group');
 define('ZBX_STYLE_PAGING_BTN_CONTAINER', 'paging-btn-container');
 define('ZBX_STYLE_PAGING_SELECTED', 'paging-selected');
 define('ZBX_STYLE_PAGE_TITLE', 'page-title-general');
@@ -1846,6 +1880,7 @@ define('ZBX_STYLE_WARNING_BG', 'warning-bg');
 define('ZBX_STYLE_WIDGET_URL', 'widget-url');
 define('ZBX_STYLE_BLINK_HIDDEN', 'blink-hidden');
 define('ZBX_STYLE_YELLOW', 'yellow');
+define('ZBX_STYLE_YELLOW_BG', 'yellow-bg');
 define('ZBX_STYLE_FIELD_LABEL_ASTERISK', 'form-label-asterisk');
 define('ZBX_STYLE_PROBLEM_ICON_LIST' , 'problem-icon-list');
 define('ZBX_STYLE_PROBLEM_ICON_LIST_ITEM' , 'problem-icon-list-item');
@@ -1913,6 +1948,10 @@ define('ZBX_STYLE_HOST_INTERFACE_INPUT_EXPAND', 'interface-input-expand');
 
 define('ZBX_STYLE_ZSELECT_HOST_INTERFACE', 'z-select-host-interface');
 
+// Dashboard list table classes.
+define('ZBX_STYLE_DASHBOARD_LIST', 'dashboard-list');
+define('ZBX_STYLE_DASHBOARD_LIST_ITEM', 'dashboard-list-item');
+
 // server variables
 define('HTTPS', isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] && $_SERVER['HTTPS'] !== 'off');
 
@@ -1946,26 +1985,3 @@ define('PROBLEMS_TAG_NAME_NONE',      2);
 define('OPERATIONAL_DATA_SHOW_NONE',         0);
 define('OPERATIONAL_DATA_SHOW_SEPARATELY',   1);
 define('OPERATIONAL_DATA_SHOW_WITH_PROBLEM', 2);
-
-/**
- * The sandbox attribute enables an extra set of restrictions for the content in the iframe. Default is set to empty
- * string, which means all restrictions are applied. To disable, set to FALSE. To set a specific set of restrictions,
- * write a custom string.
- * https://www.w3.org/TR/2010/WD-html5-20100624/the-iframe-element.html#attr-iframe-sandbox
- */
-define('ZBX_IFRAME_SANDBOX', '');
-
-// HTTP headers
-/*
- * Value of HTTP X-Frame-options header.
- *
- * Supported options:
- *  - SAMEORIGIN (string) - compatible with rfc7034.
- *  - DENY (string) - compatible with rfc7034.
- *  - a list (string) of comma-separated hostnames. If hostname is not between allowed, the SAMEORIGIN option is used.
- *  - null - disable X-Frame-options header.
- */
-define('X_FRAME_OPTIONS', 'SAMEORIGIN');
-
-// Allows to set "rel" tag value "noreferer" when setting target="_blank".
-define('ZBX_NOREFERER', true);
