@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ $widget = (new CWidget())->setTitle(_('Actions'));
 
 // create form
 $actionForm = (new CForm())
-	->setId('action.edit')
+	->setId('action-form')
 	->setName('action.edit')
 	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
 	->addVar('form', $data['form'])
@@ -58,7 +58,7 @@ $condition_table = (new CTable(_('No conditions defined.')))
 $i = 0;
 
 if ($data['action']['filter']['conditions']) {
-	$actionConditionStringValues = actionConditionValueToString([$data['action']], $data['config']);
+	$actionConditionStringValues = actionConditionValueToString([$data['action']]);
 
 	foreach ($data['action']['filter']['conditions'] as $cIdx => $condition) {
 		if (!isset($condition['conditiontype'])) {
@@ -164,7 +164,9 @@ if ($data['eventsource'] == EVENT_SOURCE_TRIGGERS) {
 }
 
 // create operation table
-$operations_table = (new CTable())->setAttribute('style', 'width: 100%;');
+$operations_table = (new CTable())
+	->setId('op-table')
+	->setAttribute('style', 'width: 100%;');
 if ($data['eventsource'] == EVENT_SOURCE_TRIGGERS || $data['eventsource'] == EVENT_SOURCE_INTERNAL) {
 	$operations_table->setHeader([_('Steps'), _('Details'), _('Start in'), _('Duration'), _('Action')]);
 	$delays = count_operations_delay($data['action']['operations'], $data['action']['esc_period']);
@@ -325,7 +327,9 @@ $operation_tab->addRow(_('Operations'),
 // Recovery operation tab.
 if ($data['eventsource'] == EVENT_SOURCE_TRIGGERS || $data['eventsource'] == EVENT_SOURCE_INTERNAL) {
 	// Create operation table.
-	$operations_table = (new CTable())->setAttribute('style', 'width: 100%;');
+	$operations_table = (new CTable())
+		->setId('rec-table')
+		->setAttribute('style', 'width: 100%;');
 	$operations_table->setHeader([_('Details'), _('Action')]);
 
 	if ($data['action']['recovery_operations']) {
@@ -415,7 +419,9 @@ if ($data['eventsource'] == EVENT_SOURCE_TRIGGERS || $data['eventsource'] == EVE
 if ($data['eventsource'] == EVENT_SOURCE_TRIGGERS) {
 	$action_formname = $actionForm->getName();
 
-	$operations_table = (new CTable())->setAttribute('style', 'width: 100%;');
+	$operations_table = (new CTable())
+		->setId('ack-table')
+		->setAttribute('style', 'width: 100%;');
 	$operations_table->setHeader([_('Details'), _('Action')]);
 
 	if ($data['action']['ack_operations']) {
@@ -494,7 +500,7 @@ if ($data['eventsource'] == EVENT_SOURCE_TRIGGERS) {
 // Append tabs to form.
 $action_tabs = (new CTabView())
 	->addTab('actionTab', _('Action'), $action_tab)
-	->addTab('operationTab', _('Operations'), $operation_tab);
+	->addTab('operationTab', _('Operations'), $operation_tab, TAB_INDICATOR_OPERATIONS);
 
 if (!hasRequest('form_refresh')) {
 	$action_tabs->setSelected(0);
